/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.application.template.dao;

import java.sql.Timestamp;
import java.util.Date;
import java.util.List;
import java.util.Map;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import org.jdesigner.platform.data.Page;
import org.jdesigner.platform.db.query.NamedQuery;
import org.jdesigner.platform.db.query.TableQuery;
import org.jdesigner.platform.exception.DatabaseException;

/**
 * <B>Code DAO</B>
 * 
 * @author leesangboo
 * 
 */
public class CodeDAO extends ProjectBaseDAO {

	private static final Log log = LogFactory.getLog(CodeDAO.class);

	/**
	 * CodeDAO
	 */
	public CodeDAO() {

	}

	/**
	 * 코드 그룹 페이지를 조회한다.
	 * 
	 * @param params
	 * @param start
	 * @param range
	 * @return
	 * @throws DatabaseException
	 */
	public Page selectCodeGroupPage(Map params, int start, int range, String sort, boolean desc) throws DatabaseException {
		NamedQuery query = persistence.newNamedQuery(DAOConstants.BASE_PATH + "/CodeDAO.selectCodeGroupPage.xml", params);
		return query.execute().selectPage(start, range, sort, desc); //
	}

	/**
	 * 코드 페이지를 조회한다.
	 * 
	 * @param params
	 * @param start
	 * @param range
	 * @return
	 * @throws DatabaseException
	 */
	public Page selectCodePage(Map params, int start, int range, String sort, boolean desc) throws DatabaseException {
		NamedQuery query = persistence.newNamedQuery(DAOConstants.BASE_PATH + "/CodeDAO.selectCodePageNamed.xml", params);
		Page page = query.execute().selectPage(start, range, sort, desc); //
		log.debug("selectCodePage = [" + page + "]");
		return page;
	}

	/**
	 * 그룹코드 옵션 목록을 반환한다.
	 * 
	 * @return
	 * @throws DatabaseException
	 */
	public List selectCodeGroupOptionList() throws DatabaseException {
		NamedQuery query = persistence.newNamedQuery(DAOConstants.BASE_PATH + "/CodeDAO.selectCodeGroupOptionList.xml");
		return query.execute().selectList(); //
	}

	/**
	 * 언어 목록을 반환한다.
	 * 
	 * @return
	 * @throws DatabaseException
	 */
	public List selectLanguageList() throws DatabaseException {
		NamedQuery query = persistence.newNamedQuery(DAOConstants.BASE_PATH + "/CodeDAO.selectLanguageList.xml");
		return query.execute().selectList(); //
	}

	/**
	 * 코드를 입력한다.
	 * 
	 * @param params
	 * @throws DatabaseException
	 */
	public void insertCode(Map params) throws DatabaseException {
		params.put("insert_date", new Timestamp(new Date().getTime()));
		TableQuery query = persistence.newTableQuery("PLF_COMMON_CODE", params);
		query.execute().insert();
	}

	/**
	 * 코드를 수정한다.
	 * 
	 * @param params
	 * @throws DatabaseException
	 */
	public void updateCode(Map params) throws DatabaseException {
		params.put("last_update_date", new Timestamp(new Date().getTime()));
		TableQuery query = persistence.newTableQuery("PLF_COMMON_CODE", params, true);
		query.execute().update();
	}

	/**
	 * 코드를 삭제한다.
	 * 
	 * @param params
	 * @throws DatabaseException
	 */
	public void deleteCode(Map params) throws DatabaseException {
		TableQuery query = persistence.newTableQuery("PLF_COMMON_CODE", params);
		query.execute().delete();
	}

	/**
	 * 코드를 조회한다.
	 * 
	 * @param params
	 * @throws DatabaseException
	 */
	public Map selectCode(Map params) throws DatabaseException {
		TableQuery query = persistence.newTableQuery("PLF_COMMON_CODE", params);
		return query.execute().selectByPrimaryKey();
	}

	/**
	 * 코드 그룹을 조회한다.
	 * 
	 * @param params
	 * @throws DatabaseException
	 */
	public Map selectCodeGroup(Map params) throws DatabaseException {
		TableQuery query = persistence.newTableQuery("PLF_COMMON_CODE_GROUP", params);
		return query.execute().selectByPrimaryKey();
	}

	/**
	 * 코드 그룹을 입력한다.
	 * 
	 * @param params
	 * @throws DatabaseException
	 */
	public void insertCodeGroup(Map params) throws DatabaseException {
		params.put("insert_date", new Timestamp(new Date().getTime()));
		TableQuery query = persistence.newTableQuery("PLF_COMMON_CODE_GROUP", params);
		query.execute().insert();

	}

	/**
	 * 코드 그룹을 수정한다.
	 * 
	 * @param params
	 * @throws DatabaseException
	 */
	public void updateCodeGroup(Map params) throws DatabaseException {
		params.put("last_update_date", new Timestamp(new Date().getTime()));
		TableQuery query = persistence.newTableQuery("PLF_COMMON_CODE_GROUP", params, true);
		query.execute().update();
	}

	/**
	 * 코드그룹을 삭제한다.
	 * 
	 * @param params
	 * @throws DatabaseException
	 */
	public void deleteCodeGroup(Map params) throws DatabaseException {
		TableQuery query = persistence.newTableQuery("PLF_COMMON_CODE_GROUP", params);
		query.execute().delete();
	}

}
