/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.application.template.dao;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import org.jdesigner.platform.data.DataMap;
import org.jdesigner.platform.data.Page;
import org.jdesigner.platform.db.query.NamedQuery;
import org.jdesigner.platform.db.query.TableQuery;
import org.jdesigner.platform.exception.DatabaseException;
import org.jdesigner.platform.util.DateUtils;

import org.jdesigner.application.template.service.CommonServiceException;

/**
 * SecurityDAO
 * 
 * @author leesangboo
 * 
 */
public class SecurityDAO extends ProjectBaseDAO {

	private static final Log log = LogFactory.getLog(SecurityDAO.class);

	public SecurityDAO() {

	}

	public boolean checkLogin(String username, String password) throws DatabaseException {
		Map params = new HashMap();
		params.put("username", username);
		params.put("password", password);
		NamedQuery query = persistence.newNamedQuery(DAOConstants.BASE_PATH + "/LoginDAO.checkLogin.xml", params);
		List list = query.execute().selectList(); //
		return (list != null && list.size() > 0) ? true : false;
	}

	public List getUserRoles(String username) throws DatabaseException {
		Map params = new HashMap();
		params.put("username", username);
		NamedQuery query = persistence.newNamedQuery(DAOConstants.BASE_PATH + "/LoginDAO.getUserRole.xml", params);
		List list = query.execute().selectList(); //
		log.debug("role list = [" + list + "]");
		List roleList = new ArrayList();
		for (int i = 0; list != null && i < list.size(); i++) {
			DataMap data = (DataMap) list.get(i);
			roleList.add(data.getString("role_id")); //
		}
		return roleList;
	}

	public Page selectAuthGroupPage(Map params, int start, int range, String sort, boolean desc) throws DatabaseException {
		NamedQuery query = persistence.newNamedQuery(DAOConstants.BASE_PATH + "/SecurityDAO.selectAuthGroupPage.xml", params);
		return query.execute().selectPage(start, range, sort, desc); //
	}

	public Map selectAuthGroup(Map params) throws DatabaseException {
		TableQuery query = persistence.newTableQuery("PLF_AUTH_GROUP", params);
		return query.execute().selectByPrimaryKey();
	}

	public void insertAuthGroup(Map params, List auth_role_list) throws DatabaseException {
		try {

			persistence.startTransaction();

			params.put("insert_date", new Timestamp(new Date().getTime()));

			TableQuery query = persistence.newTableQuery("PLF_AUTH_GROUP", params);
			query.execute().insert();

			for (int i = 0; auth_role_list != null && i < auth_role_list.size(); i++) {
				Map map = (Map) auth_role_list.get(i);
				map.put("group_id", params.get("group_id"));
				TableQuery rtq = persistence.newTableQuery("PLF_AUTH_GROUP_ROLE", map);
				rtq.execute().insert();
			}

			persistence.commitTransaction();
		} catch (Exception ex) {
			throw new DatabaseException(ex.getMessage());
		} finally {
			persistence.endTransaction();
		}
	}

	public void updateAuthGroup(Map params, List auth_role_list) throws DatabaseException {
		try {
			params.put("last_update_date", new Timestamp(new Date().getTime()));

			persistence.startTransaction();

			TableQuery query = persistence.newTableQuery("PLF_AUTH_GROUP", params);
			query.execute().update();

			TableQuery detailQuery = persistence.newTableQuery("PLF_AUTH_GROUP_ROLE", new String[] { "group_id" }, params);
			detailQuery.execute().delete();

			for (int i = 0; auth_role_list != null && i < auth_role_list.size(); i++) {
				Map map = (Map) auth_role_list.get(i);
				map.put("group_id", params.get("group_id"));
				TableQuery rtq = persistence.newTableQuery("PLF_AUTH_GROUP_ROLE", map);
				rtq.execute().insert();
			}

			persistence.commitTransaction();
		} catch (Exception ex) {
			throw new DatabaseException(ex.getMessage());
		} finally {
			persistence.endTransaction();
		}
	}

	public void deleteAuthGroup(Map params) throws DatabaseException {
		try {

			persistence.startTransaction();

			TableQuery query = persistence.newTableQuery("PLF_AUTH_GROUP", params);
			query.execute().delete();

			TableQuery detailQuery = persistence.newTableQuery("PLF_AUTH_GROUP_ROLE", new String[] { "group_id" }, params);
			detailQuery.execute().delete();

			persistence.commitTransaction();
		} catch (Exception ex) {
			throw new DatabaseException(ex.getMessage());
		} finally {
			persistence.endTransaction();
		}
	}

	public Page selectAuthRolePage(Map params, int start, int range, String sort, boolean desc) throws DatabaseException {
		NamedQuery query = persistence.newNamedQuery(DAOConstants.BASE_PATH + "/SecurityDAO.selectAuthRolePage.xml", params);
		return query.execute().selectPage(start, range, sort, desc); //
	}

	public List selectAuthGroupRoleList(Map params) throws DatabaseException {
		NamedQuery query = persistence.newNamedQuery(DAOConstants.BASE_PATH + "/SecurityDAO.selectAuthGroupRoleList.xml", params);
		return query.execute().selectList(); //
	}

	public Map selectAuthRole(Map params) throws CommonServiceException {
		TableQuery query = persistence.newTableQuery("PLF_AUTH_ROLE", params);
		return query.execute().selectByPrimaryKey();
	}

	public void insertAuthRole(Map params) throws CommonServiceException {
		params.put("insert_date", new Timestamp(new Date().getTime()));
		TableQuery query = persistence.newTableQuery("PLF_AUTH_ROLE", params);
		query.execute().insert();
	}

	public void updateAuthRole(Map params) throws CommonServiceException {
		params.put("last_update_date", new Timestamp(new Date().getTime()));
		TableQuery query = persistence.newTableQuery("PLF_AUTH_ROLE", params, true);
		query.execute().update();
	}

	public void deleteAuthRole(Map params) throws CommonServiceException {
		TableQuery query = persistence.newTableQuery("PLF_AUTH_ROLE", params);
		query.execute().delete();
	}

	public Map selectUserLoginHistoryByLast(Map params) throws CommonServiceException {
		NamedQuery query = persistence.newNamedQuery(DAOConstants.BASE_PATH + "/SecurityDAO.selectUserLoginHistoryByLast.xml", params);
		return query.execute().selectMap(); //
	}

	public void insertLoginHistory(Map params) throws DatabaseException {
		params.put(INSERT_DATE_COLUMN, DateUtils.getToTimestamp()); //
		TableQuery query = persistence.newTableQuery("PLF_USER_LOGIN_HISTORY", params);
		query.execute().insert();
	}
}
