/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.jdesigner.application.template.service;

import java.util.Map;

import net.sf.jsr107cache.Cache;

/**
 * <B>JSR 107 캐쉬 서비스</B>
 * 
 * <pre> EHCache를 상속하는 캐쉬 서비스 </pre>
 * 
 * @author leesangboo
 * 
 */
public interface CacheService {

	/**
	 * 캐쉬를 생성한다.
	 * 
	 * <pre> EX) Map configuration ==&gt; Map config = new HashMap(); config.put(&quot;name&quot;, &quot;test&quot;);
	 * config.put(&quot;maxElementsInMemory&quot;, &quot;10&quot;); config.put(&quot;memoryStoreEvictionPolicy&quot;, &quot;LFU&quot;);
	 * config.put(&quot;overflowToDisk&quot;, &quot;true&quot;); config.put(&quot;eternal&quot;, &quot;false&quot;);
	 * config.put(&quot;timeToLiveSeconds&quot;, &quot;5&quot;); config.put(&quot;timeToIdleSeconds&quot;, &quot;5&quot;);
	 * config.put(&quot;diskPersistent&quot;, &quot;false&quot;); config.put(&quot;diskExpiryThreadIntervalSeconds&quot;, &quot;120&quot;); </pre>
	 * 
	 * @throws CommonServiceException
	 */
	public void createCache(String key, Map configuration) throws CommonServiceException;

	/**
	 * 캐쉬를 반환한다.
	 * 
	 * @param key
	 * @throws CommonServiceException
	 */
	public Cache getCache(String key) throws CommonServiceException;

}
