/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.jdesigner.application.template.service;

import org.jdesigner.application.template.service.impl.AnalysisServiceImpl;
import org.jdesigner.application.template.service.impl.AsynchronousServiceImpl;
import org.jdesigner.application.template.service.impl.CacheServiceImpl;
import org.jdesigner.application.template.service.impl.CommonCodeServiceImpl;
import org.jdesigner.application.template.service.impl.ExcelServiceImpl;
import org.jdesigner.application.template.service.impl.FTPServiceImpl;
import org.jdesigner.application.template.service.impl.FileUploadServiceImpl;
import org.jdesigner.application.template.service.impl.HomeServiceImpl;
import org.jdesigner.application.template.service.impl.I18NServiceImpl;
import org.jdesigner.application.template.service.impl.MailServiceImpl;
import org.jdesigner.application.template.service.impl.MenuServiceImpl;
import org.jdesigner.application.template.service.impl.NoticeServiceImpl;
import org.jdesigner.application.template.service.impl.PortletServiceImpl;
import org.jdesigner.application.template.service.impl.SecurityServiceImpl;
import org.jdesigner.application.template.service.impl.TransactionServiceImpl;
import org.jdesigner.application.template.service.impl.UserServiceImpl;

/**
 * <B>공통 서비스 팩토리</B>
 * 
 * @author leesangboo
 * 
 */
public class CommonServiceFactory {

	/**
	 * 공지사항 서비스를 반환한다.
	 * 
	 * @return
	 */
	public static NoticeService getNoticeService() {
		return new NoticeServiceImpl();
	}

	/**
	 * 포틀릿 서비스를 반환한다.
	 * 
	 * @return
	 */
	public static PortletService getPortletService() {
		return new PortletServiceImpl();
	}

	/**
	 * 홈 서비스를 반환한다.
	 * 
	 * @return
	 */
	public static HomeService getHomeService() {
		return new HomeServiceImpl();
	}

	/**
	 * 공통 코드 서비스를 반환한다.
	 * 
	 * @return
	 */
	public static CommonCodeService getCommonCodeService() {
		return new CommonCodeServiceImpl();
	}

	/**
	 * 메뉴 서비스를 반환한다.
	 * 
	 * @return
	 */
	public static MenuService getMenuService() {
		return new MenuServiceImpl();
	}

	/**
	 * 사용자 서비스를 반환한다.
	 * 
	 * @return
	 */
	public static UserService getUserService() {
		return new UserServiceImpl();
	}

	/**
	 * 보안 서비스를 반환한다.
	 * 
	 * @return
	 */
	public static SecurityService getSecurityService() {
		return new SecurityServiceImpl();
	}

	/**
	 * 통계 서비스를 반환한다.
	 * 
	 * @return
	 */
	public static AnalysisService getAnalysisService() {
		return new AnalysisServiceImpl();
	}

	/**
	 * 메일 서비스를 반환한다.
	 * 
	 * @return
	 */
	public static MailService getMailService() {
		return new MailServiceImpl();
	}

	/**
	 * 캐쉬 서비스를 반환한다.
	 * 
	 * @return
	 */
	public static CacheService getCacheService() {
		return new CacheServiceImpl();
	}

	/**
	 * 파일 업로드 서비스를 반환한다.
	 * 
	 * @return
	 */
	public static FileUploadService getFileUploadService() {
		return new FileUploadServiceImpl();
	}

	/**
	 * 게시판 파일 업로드 서비스를 반환한다.
	 * 
	 * @return
	 */
	public static FileUploadService getBbsFileUploadService() {
		return new FileUploadServiceImpl();
	}

	/**
	 * 엑셀 서비스를 반환한다.
	 * 
	 * @return
	 */
	public static ExcelService getExcelService() {
		return new ExcelServiceImpl();
	}

	/**
	 * I18N 서비스를 반환한다.
	 * 
	 * @return
	 */
	public static I18NService getI18NService() {
		return new I18NServiceImpl();
	}

	/**
	 * 트랜잭션 서비스를 반환한다.
	 * 
	 * @return
	 */
	public static TransactionService getTransactionService() {
		return new TransactionServiceImpl();
	}

	/**
	 * FTP 서비스를 반환한다.
	 * 
	 * @return
	 */
	public static FTPService getFTPService() {
		return new FTPServiceImpl();
	}

	/**
	 * 비동기 실행 서비스를 반환한다.
	 * 
	 * @return
	 */
	public static AsynchronousService getAsynchronousService() {
		return new AsynchronousServiceImpl();
	}

}
