/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.jdesigner.application.template.service;

import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;

import org.jdesigner.platform.web.fileupload.MultiFileUpload;
import org.jdesigner.platform.web.fileupload.SingleFileUpload;

/**
 * <B>파일 업로드 서비스</B>
 * 
 * @author SangBoo Lee
 * @date 2009. 11. 17.
 * @since 1.0
 */
public interface FileUploadService {

	/**
	 * 파일 업로드 맵핑 ID를 생성한다.
	 * 
	 * @param request
	 * @return
	 * @throws CommonServiceException
	 */
	public String createMappingID(HttpServletRequest request) throws CommonServiceException;

	/**
	 * 파일을 업로드한다.
	 * 
	 * @param request
	 * @return
	 * @throws CommonServiceException
	 */
	public List upload(HttpServletRequest request) throws CommonServiceException;

	/**
	 * TEMP 디렉토리에 업로드된 파일 리스트를 반환한다.
	 * 
	 * @param request
	 * @param mappingID
	 *            - 파입 업로드 맵핑 ID
	 * @param targetFileName
	 *            - 대상 파일명
	 * @param outDirectory
	 *            - 저장될 디렉토리
	 * @return Map - 저장된 파일 맵
	 * @throws CommonServiceException
	 */
	public Map saveSingleFile(String mappingID, String targetFileName, String outDirectory) throws CommonServiceException;

	/**
	 * TEMP 디렉토리에 업로드된 파일 리스트를 반환한다.
	 * 
	 * @param upload
	 * @param outDirectory
	 * @return
	 * @throws CommonServiceException
	 */
	public Map saveSingleFile(SingleFileUpload upload, String outDirectory) throws CommonServiceException;

	/**
	 * TEMP 디렉토리에 업로드된 게 파일 리스트를 반환한다.
	 * 
	 * @param request
	 * @param mappingID
	 *            - 파입 업로드 맵핑 ID
	 * @param targetFileNames
	 *            - 대상 파일명 배열
	 * @param outDirectory
	 *            - 저장될 디렉토리
	 * @return List<Map> - 저장된 파일 맵 리스트
	 * @throws CommonServiceException
	 */
	public List saveMultiFile(String mappingID, String[] targetFileNames, String outDirectory) throws CommonServiceException;

	/**
	 * TEMP 디렉토리에 업로드된 게 파일 리스트를 반환한다.
	 * 
	 * @param upload
	 * @param outDirectory
	 * @return
	 * @throws CommonServiceException
	 */
	public List saveMultiFile(MultiFileUpload upload, String outDirectory) throws CommonServiceException;

	/**
	 * 임시저장 파일 기본 디렉토리 경로를 반환한다.
	 * 
	 * @return
	 * @throws CommonServiceException
	 */
	public String getTempBaseDirPath() throws CommonServiceException;

}
