/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.application.template.service.config;

import java.io.File;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.dom4j.Document;
import org.dom4j.Node;

import org.jdesigner.platform.context.ApplicationContextFactory;
import org.jdesigner.platform.util.Dom4jUtils;

/**
 * CacheConfigFactory
 * 
 * @author SangBoo Lee
 * @date 2010. 2. 26.
 * @since 1.0
 * 
 */
public class CacheConfigurationLoader {

	private static final Log log = LogFactory.getLog(CacheConfigurationLoader.class);

	private static final String CACHE_NODE_XPATH = "/cache-config/cache";
	private static final String PROPERTY_NODE_XPATH = "property";

	/**
	 * 설정파일을 로드한다.
	 * 
	 * @param filePath
	 * @return
	 */
	public List load(String filePath) {
		//
		log.info("Cache configuration xml file : path=[" + filePath + "]");
		//
		List cacheList = parseDocument(filePath);
		if (cacheList != null && cacheList.size() > 0) {
			for (int i = 0; i < cacheList.size(); i++) {
				Map configuration = (Map) cacheList.get(i);
				log.debug("Cache configuration = [" + configuration.toString() + "]");
			}

		} else {
			log.warn("Cash, one does not exist.");
		}
		return cacheList;
	}

	/**
	 * XML 설정 도큐먼트를 파싱한다.
	 * 
	 * @return
	 */
	private List parseDocument(String CONFIG_PATH) {

		List cacheList = new ArrayList();

		try {
			String appPath = ApplicationContextFactory.getInstance().getApplicationContext().getAppPath();
			File configFile = new File(appPath, CONFIG_PATH);

			Document document = Dom4jUtils.getXmlDocument(configFile);
			List nodeList = document.selectNodes(CACHE_NODE_XPATH);
			for (int i = 0; i < nodeList.size(); i++) {
				//
				Node node = (Node) nodeList.get(i);
				String name = node.valueOf("@" + "name");
				Map configuration = new HashMap();
				configuration.put("name", name);
				//
				List propertyList = node.selectNodes(PROPERTY_NODE_XPATH);
				if (propertyList == null || propertyList.size() < 1) {
					log.error("Cache of the property has not been set : name=[" + name + "]");
				}
				// log.info("propertyList.size()=" + propertyList.size());
				for (int j = 0; j < propertyList.size(); j++) {
					Node property = (Node) propertyList.get(j);
					String key = property.valueOf("@" + "name").trim();
					String value = property.getText().trim();
					configuration.put(key, value);
				}
				//
				cacheList.add(configuration);
			}
		} catch (Exception ex) {
			String msg = "Cannot parse cache config xml document : " + ex.getMessage();
			log.error(msg, ex);
		}
		return cacheList;
	}

}
