/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.application.template.service.impl;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import org.jdesigner.application.template.domain.AsychronousWorker;
import org.jdesigner.application.template.service.AsynchronousService;
import org.jdesigner.application.template.service.CommonServiceException;

import edu.emory.mathcs.backport.java.util.concurrent.Callable;
import edu.emory.mathcs.backport.java.util.concurrent.ExecutionException;
import edu.emory.mathcs.backport.java.util.concurrent.ExecutorService;
import edu.emory.mathcs.backport.java.util.concurrent.Executors;
import edu.emory.mathcs.backport.java.util.concurrent.Future;

/**
 * AsynchronousServiceImpl
 * 
 * @author leesangboo
 * 
 */
public class AsynchronousServiceImpl implements AsynchronousService {

	private static final Log log = LogFactory.getLog(AsynchronousServiceImpl.class);

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesigner.application.template.service.AsynchronousService#process(org.jdesigner.application.template.domain.AsychronousWorker)
	 */
	public Object process(final AsychronousWorker worker) throws CommonServiceException {
		Object result = null;
		try {
			ExecutorService es = Executors.newFixedThreadPool(3);
			final Future future = es.submit(new Callable() {
				public Object call() throws Exception {
					return worker.doWork();
				}
			});

			try {
				result = future.get();
			} catch (InterruptedException e) {
			} catch (ExecutionException e) {
			}
			return result;
		} catch (Exception ex) {
			String msg = "Failed excute asynchronous work : " + ex.getMessage();
			log.error(msg, ex);
			throw new CommonServiceException(msg, ex);
		}
	}

}
