/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.application.template.service.lifecycle;

import java.util.List;
import java.util.Map;

import javax.servlet.ServletContext;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import org.jdesigner.application.template.service.CacheService;
import org.jdesigner.application.template.service.CommonServiceFactory;
import org.jdesigner.application.template.service.config.CacheConfigurationLoader;

/**
 * CacheLifecycle
 * 
 * @author SangBoo Lee
 * @date 2010. 2. 26.
 * @since 1.0
 * 
 */
public class CacheLifecycle {

	private static final Log log = LogFactory.getLog(CacheLifecycle.class);

	private static class CacheLifecycleHolder {
		static CacheLifecycle instance = new CacheLifecycle();
	}

	public static CacheLifecycle getInstance() {
		return CacheLifecycleHolder.instance;
	}

	/**
	 * 캐쉬를 시작한다.
	 * 
	 * @param context
	 * @param config
	 */
	public void start(ServletContext context, String config) {
		try {
			//
			log.info("Cache service starting...");
			CacheConfigurationLoader factory = new CacheConfigurationLoader();
			List cacheList = factory.load(config);
			for (int i = 0; cacheList != null && i < cacheList.size(); i++) {
				Map configuration = (Map) cacheList.get(i);
				CacheService cacheService = CommonServiceFactory.getCacheService();
				cacheService.createCache((String) configuration.get("name"), configuration);
			}

			log.info("Running total cache size=[" + cacheList.size() + "]");

			log.info("Cache service has been started.");
		} catch (Exception e) {
			String msg = "Cache service start failed : " + e.getMessage();
			log.error(msg, e);
			throw new RuntimeException(msg);
		}
	}

	public void stop(ServletContext context) {
		//
	}

}
