/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.application.template.web.file;

import java.io.File;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionMapping;

import org.jdesigner.platform.util.StringUtils;

/**
 * File Download Actoin
 * 
 * @author SangBoo Lee
 * @date 2010. 1. 18.
 * @since 1.0
 * 
 */
public class FileDownloadAction extends DownloadAction {

	private static final Log log = LogFactory.getLog(FileDownloadAction.class);

	public static final String FILE_DIR_KEY = "_FILE_DIR";
	public static final String FILE_NAME_KEY = "_FILE_NAME";
	public static final String FILE_CONTENT_TYPE_KEY = "_FILE_CONTENT_TYPE";
	public static final String SAVE_NAME_KEY = "_SAVE_NAME";

	/*
	 * (non-Javadoc)
	 * 
	 * @see #getStreamInfo(org.apache.struts .action.ActionMapping, org.apache.struts.action.ActionForm, javax.servlet.http.HttpServletRequest,
	 * javax.servlet.http.HttpServletResponse)
	 */
	protected StreamInfo getStreamInfo(ActionMapping mapping, ActionForm form, HttpServletRequest request, HttpServletResponse response) throws Exception {

		//
		HttpSession session = request.getSession();

		//
		String fileDir = (String) session.getAttribute(FILE_DIR_KEY);
		String fileName = (String) session.getAttribute(FILE_NAME_KEY);
		String saveName = (String) session.getAttribute(SAVE_NAME_KEY);
		String fileContentType = (String) session.getAttribute(FILE_CONTENT_TYPE_KEY);

		//
		if (StringUtils.isEmpty(fileDir) || StringUtils.isEmpty(fileName) || StringUtils.isEmpty(fileContentType)) {
			String msg = "Download the session key value does not exist : " + "fileDir=[" + fileDir + "], " + "fileName=[" + fileName + "], " + "fileContentType=[" + fileContentType + "]";
			log.error(msg);
			throw new Exception(msg);
		}

		// Set the content disposition
		response.setHeader("Content-disposition", "attachment; filename=" + java.net.URLEncoder.encode(saveName, response.getCharacterEncoding()));
		response.setHeader("Content-Transfer-Encoding", "binary;");
		response.setHeader("Pragma", "no-cache;");
		response.setHeader("Expires", "-1;");

		//
		String contentType = fileContentType;
		String target_file_path = StringUtils.cleanPath(fileDir + "/" + fileName);
		File file = new File(target_file_path);
		if (!file.exists()) {
			String msg = "Not found target download file : path=[" + target_file_path + "]";
			log.error(msg);
			throw new Exception(msg);
		}

		//
		return new FileStreamInfo(contentType, file);

	}
}
