/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.application.template.web.home;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import org.jdesigner.platform.web.form.Form;
import org.jdesigner.platform.web.form.InputsList;

import org.jdesigner.application.template.service.CommonServiceFactory;
import org.jdesigner.application.template.service.HomeService;
import org.jdesigner.application.template.service.SecurityService;
import org.jdesigner.application.template.web.TemplateBaseActionBean;

/**
 * HomeBean
 * 
 * @author leesangboo
 * 
 */
public class HomeBean extends TemplateBaseActionBean {

	private static final long serialVersionUID = 1L;

	private static final Log log = LogFactory.getLog(HomeBean.class);

	private static final String DEFAULT_WEBTOPLET_LAYOUT_USERNAME = "DEFAULT_WEBTOPLET_LAYOUT";

	private HomeService home_service;
	private SecurityService security_service;

	private String column_align;
	private Form webtoplet;
	private InputsList webtoplet_list;

	private List unselected_webtoplet_list;

	private List left_webtoplet_list;
	private List right_webtoplet_list;

	public HomeBean() {
		init(); //
	}

	public void init() {
		log.info("ActionBean[" + this.getClass() + "] initialize...");
		home_service = CommonServiceFactory.getHomeService();
		security_service = CommonServiceFactory.getSecurityService();
		//
		column_align = "";
		webtoplet = new Form();
		webtoplet_list = new InputsList();
		//
		unselected_webtoplet_list = new ArrayList();
		//
		left_webtoplet_list = new ArrayList();
		right_webtoplet_list = new ArrayList();
	}

	public String home() throws Exception {
		Map params = new HashMap();
		params.put("username", security_service.getUserLogin().getUsername());
		left_webtoplet_list = home_service.getLeftWebTopLetList(params);
		right_webtoplet_list = home_service.getRightWebTopLetList(params);
		if (left_webtoplet_list == null && right_webtoplet_list == null) {
			params.put("username", DEFAULT_WEBTOPLET_LAYOUT_USERNAME);
			left_webtoplet_list = home_service.getLeftWebTopLetList(params);
			right_webtoplet_list = home_service.getRightWebTopLetList(params);
			//
			super.setServerMessage("home.webtop.initialize");
		}
		return SUCCESS;
	}

	public String openWebTopLetDialog() throws Exception {
		Map params = new HashMap();
		params.put("username", security_service.getUserLogin().getUsername());
		unselected_webtoplet_list = home_service.selectUndselectedWebTopLetList(params);
		return SUCCESS;
	}

	public String reorderWebTopLetLayout() throws Exception {
		String username = security_service.getUserLogin().getUsername();
		home_service.saveWebTopLetLayout(username, column_align, webtoplet_list, true);
		return NULL;
	}

	public String saveWebTopLetLayout() throws Exception {
		String username = security_service.getUserLogin().getUsername();
		home_service.saveWebTopLetLayout(username, column_align, webtoplet_list, false);
		return NULL;
	}

	public String closeWebTopLet() throws Exception {
		String username = security_service.getUserLogin().getUsername();
		home_service.closeWebTopLet(username, webtoplet);
		return NULL;
	}

	public List getLeft_webtoplet_list() {
		return left_webtoplet_list;
	}

	public void setLeft_webtoplet_list(List left_webtoplet_list) {
		this.left_webtoplet_list = left_webtoplet_list;
	}

	public List getRight_webtoplet_list() {
		return right_webtoplet_list;
	}

	public void setRight_webtoplet_list(List right_webtoplet_list) {
		this.right_webtoplet_list = right_webtoplet_list;
	}

	public HomeService getHome_service() {
		return home_service;
	}

	public void setHome_service(HomeService home_service) {
		this.home_service = home_service;
	}

	public SecurityService getSecurity_service() {
		return security_service;
	}

	public void setSecurity_service(SecurityService security_service) {
		this.security_service = security_service;
	}

	public InputsList getWebtoplet_list() {
		return webtoplet_list;
	}

	public void setWebtoplet_list(InputsList webtoplet_list) {
		this.webtoplet_list = webtoplet_list;
	}

	public Form getWebtoplet() {
		return webtoplet;
	}

	public void setWebtoplet(Form webtoplet) {
		this.webtoplet = webtoplet;
	}

	public List getUnselected_webtoplet_list() {
		return unselected_webtoplet_list;
	}

	public void setUnselected_webtoplet_list(List unselected_webtoplet_list) {
		this.unselected_webtoplet_list = unselected_webtoplet_list;
	}

	public String getColumn_align() {
		return column_align;
	}

	public void setColumn_align(String column_align) {
		this.column_align = column_align;
	}

}
