/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.application.template.web.system;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import org.jdesigner.platform.web.form.Form;
import org.jdesigner.platform.web.form.FormMode;
import org.jdesigner.platform.web.grid.Grid;

import org.jdesigner.application.template.service.CommonServiceFactory;
import org.jdesigner.application.template.service.SecurityService;
import org.jdesigner.application.template.web.TemplateBaseActionBean;

/**
 * 인증 권한 액션 빈
 * 
 * @author leesangboo
 * 
 */
public class AuthRoleBean extends TemplateBaseActionBean {

	private static final long serialVersionUID = 1L;

	private static final Log log = LogFactory.getLog(AuthRoleBean.class);

	private SecurityService security_service;

	private Form search;
	private Form form;
	private Grid grid;

	public AuthRoleBean() {
		log.info("ActionBean[" + this.getClass() + "] initialize...");
		init(); //
	}

	public void init() {
		security_service = CommonServiceFactory.getSecurityService();

		form = new Form();
		search = new Form();
		grid = new Grid();
	}

	public void reset() {
		//
	}

	public String index() throws Exception {
		reset();
		return SUCCESS;
	}

	public String grid() throws Exception {
		grid = new Grid(security_service.selectAuthRolePage(search, grid.getStart(), grid.getRange(), grid.getSort(), grid.isDesc()));
		return Grid.FORWARD;
	}

	public String add() throws Exception {
		form.setMode(FormMode.INSERT);
		return SUCCESS;
	}

	public String edit() throws Exception {
		form.setMode(FormMode.UPDATE);
		form.putAll(security_service.selectAuthRole(form));
		return SUCCESS;
	}

	public String insert() throws Exception {
		security_service.insertAuthRole(form);
		super.setServerMessage("common.insert.success");
		return SUCCESS;
	}

	public String update() throws Exception {
		security_service.updateAuthRole(form);
		super.setServerMessage("common.insert.success");
		return SUCCESS;
	}

	public String delete() throws Exception {
		security_service.deleteAuthRole(form);
		super.setServerMessage("common.insert.success");
		return SUCCESS;
	}

	public Form getForm() {
		return form;
	}

	public void setForm(Form form) {
		this.form = form;
	}

	public Form getSearch() {
		return search;
	}

	public void setSearch(Form search) {
		this.search = search;
	}

	public Grid getGrid() {
		return grid;
	}

	public void setGrid(Grid grid) {
		this.grid = grid;
	}

}
