/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.application.template.web.system;

import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import org.jdesigner.platform.util.DateUtils;
import org.jdesigner.platform.web.form.Form;
import org.jdesigner.platform.web.grid.Grid;

import org.jdesigner.application.template.service.AnalysisService;
import org.jdesigner.application.template.service.CommonCodeService;
import org.jdesigner.application.template.service.CommonServiceFactory;
import org.jdesigner.application.template.web.TemplateBaseActionBean;

/**
 * 시스템 로그 액션 빈
 * 
 * @author leesangboo
 * 
 */
public class SystemLogBean extends TemplateBaseActionBean {

	private static final long serialVersionUID = 1L;

	private static final Log log = LogFactory.getLog(SystemLogBean.class);

	private CommonCodeService common_code_service;
	private AnalysisService analysis_service;

	private Form search;
	private Form form;
	private Grid grid;

	private List trace_list;

	public SystemLogBean() {
		log.info("ActionBean[" + this.getClass() + "] initialize...");
		init(); //
	}

	public void init() {
		common_code_service = CommonServiceFactory.getCommonCodeService();
		analysis_service = CommonServiceFactory.getAnalysisService();
		form = new Form();
		search = new Form();
		grid = new Grid();
		//
		trace_list = new ArrayList();
	}

	public String index() throws Exception {
		search.put("log_from_date", new Date());
		search.put("log_to_date", new Date());
		return SUCCESS;
	}

	public String chartLog() throws Exception {
		//
		Map params = new HashMap();
		String base_date = DateUtils.dateToISO(new java.util.Date(), true);
		String term = super.getRequest().getParameter("term");
		params.put("base_date", base_date);
		params.put("term", term);
		params.put("minus_day", new Long(7)); // 일주일

		//
		List chart1_category_data = analysis_service.selectSystemLogDayCategoryList(params);

		//
		params.put("priority", "DEBUG");
		List chart1_debug_data = analysis_service.selectSystemLogCountList(params);

		//
		params.put("priority", "INFO");
		List chart1_info_data = analysis_service.selectSystemLogCountList(params);

		//
		params.put("priority", "WARN");
		List chart1_warn_data = analysis_service.selectSystemLogCountList(params);

		//
		params.put("priority", "ERROR");
		List chart1_error_data = analysis_service.selectSystemLogCountList(params);

		super.getRequest().setAttribute("chart1_category_data", chart1_category_data);
		super.getRequest().setAttribute("chart1_debug_data", chart1_debug_data);
		super.getRequest().setAttribute("chart1_info_data", chart1_info_data);
		super.getRequest().setAttribute("chart1_warn_data", chart1_warn_data);
		super.getRequest().setAttribute("chart1_error_data", chart1_error_data);

		return SUCCESS;
	}

	public String grid() throws Exception {
		grid = new Grid(analysis_service.selectSystemLogPage(search, grid.getStart(), grid.getRange(), grid.getSort(), grid.isDesc()));
		return Grid.FORWARD;
	}

	public String trace() throws Exception {
		trace_list = analysis_service.selectSystemLogByProcessID(form);
		return SUCCESS;
	}

	public CommonCodeService getCommon_code_service() {
		return common_code_service;
	}

	public void setCommon_code_service(CommonCodeService commonCodeService) {
		this.common_code_service = commonCodeService;
	}

	public Form getForm() {
		return form;
	}

	public void setForm(Form form) {
		this.form = form;
	}

	public Form getSearch() {
		return search;
	}

	public void setSearch(Form search) {
		this.search = search;
	}

	public Grid getGrid() {
		return grid;
	}

	public void setGrid(Grid grid) {
		this.grid = grid;
	}

	public AnalysisService getAnalysis_service() {
		return analysis_service;
	}

	public void setAnalysis_service(AnalysisService analysisService) {
		analysis_service = analysisService;
	}

	public List getTrace_list() {
		return trace_list;
	}

	public void setTrace_list(List traceList) {
		trace_list = traceList;
	}

}
