/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.application.template.web.system;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import org.jdesigner.platform.web.form.Form;
import org.jdesigner.platform.web.form.FormMode;
import org.jdesigner.platform.web.grid.Grid;
import org.jdesigner.platform.web.table.Table;

import org.jdesigner.application.template.service.CommonServiceFactory;
import org.jdesigner.application.template.service.UserService;
import org.jdesigner.application.template.web.TemplateBaseActionBean;

/**
 * 사용자 액션 빈
 * 
 * @author leesangboo
 * 
 */
public class UserBean extends TemplateBaseActionBean {

	private static final long serialVersionUID = 1L;

	private static final Log log = LogFactory.getLog(UserBean.class);

	private UserService user_service;

	private Form search;
	private Form form;
	private Grid grid;
	private Table auth_group_table;
	private Table auth_role_table;

	public UserBean() {
		log.info("ActionBean[" + this.getClass() + "] initialize...");
		init(); //
	}

	public void init() {
		user_service = CommonServiceFactory.getUserService();
		search = new Form();
		form = new Form();
		grid = new Grid();
		auth_group_table = new Table();
		auth_role_table = new Table();
	}

	public void reset() {
		//
	}

	public String index() throws Exception {
		reset();
		return SUCCESS;
	}

	public String grid() throws Exception {
		grid = new Grid(user_service.selectUserLoginPage(form, grid.getStart(), grid.getRange(), grid.getSort(), grid.isDesc()));
		return Grid.FORWARD;
	}

	public String add() throws Exception {
		form.setMode(FormMode.INSERT);
		return SUCCESS;
	}

	public String edit() throws Exception {
		form.setMode(FormMode.UPDATE);
		form.putAll(user_service.selectUserLogin(form));

		auth_group_table = new Table(user_service.selectUserGroupList(form));
		auth_role_table = new Table(user_service.selectUserRoleList(form));

		return (SUCCESS);
	}

	public String insert() throws Exception {
		user_service.insertUserLogin(form, auth_group_table, auth_role_table);
		setServerMessage("common.insert.success");
		return SUCCESS;
	}

	public String update() throws Exception {
		user_service.updateUserLogin(form, auth_group_table, auth_role_table);
		setServerMessage("common.update.success");
		return SUCCESS;
	}

	public String delete() throws Exception {
		user_service.deleteUserLogin(form);
		setServerMessage("common.delete.success");
		return SUCCESS;
	}

	public UserService getUserService() {
		return user_service;
	}

	public void setUserService(UserService userService) {
		this.user_service = userService;
	}

	public Form getSearch() {
		return search;
	}

	public void setSearch(Form search) {
		this.search = search;
	}

	public Form getForm() {
		return form;
	}

	public void setForm(Form form) {
		this.form = form;
	}

	public Grid getGrid() {
		return grid;
	}

	public void setGrid(Grid grid) {
		this.grid = grid;
	}

	public Table getAuth_group_table() {
		return auth_group_table;
	}

	public void setAuth_group_table(Table authGroupTable) {
		auth_group_table = authGroupTable;
	}

	public Table getAuth_role_table() {
		return auth_role_table;
	}

	public void setAuth_role_table(Table authRoleTable) {
		auth_role_table = authRoleTable;
	}

	public UserService getUser_service() {
		return user_service;
	}

	public void setUser_service(UserService user_service) {
		this.user_service = user_service;
	}

}