/*
 * JDesigner (R) Web Application Development Platform 
 * Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 * http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.jdesigner.platform.cache;

import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Properties;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import org.jdesigner.platform.cache.impl.FIFOCache;
import org.jdesigner.platform.cache.impl.LRUCache;
import org.jdesigner.platform.cache.impl.MemoryCache;

/**
 * Cache Factory
 * 
 * @author leesangboo
 * 
 */
public class CacheFactory {

	private static final Log log = LogFactory.getLog(CacheFactory.class);

	private static final Map cacheMap = Collections.synchronizedMap(new HashMap());

	/**
	 * 캐쉬 오브젝트를 생성한다.
	 * 
	 * @param id
	 * @param type
	 * @return
	 */
	public static Cache createCache(String id, int type, Properties configuration) {
		//
		if (cacheMap.containsKey(id)) {
			throw new CacheException("Aready created cache : id=[" + id + "]");
		}
		//
		Cache cache = null;
		switch (type) {
		case Cache.LRU:
			cache = new LRUCache(configuration);
			break;

		case Cache.FIFO:
			cache = new FIFOCache(configuration);
			break;

		case Cache.MEMORY:
			cache = new MemoryCache(configuration);
			break;
		}
		cacheMap.put(id, cache);
		log.info("Create new cache object : id=[" + id + "], type=[" + cache.getClass() + "]");
		return cache;
	}

	/**
	 * 캐쉬 오브젝트를 반환한다.
	 * 
	 * @param id
	 * @return
	 */
	public static Cache getCache(String id) {
		return (Cache) cacheMap.get(id);
	}

}
