/*
 * JDesigner (R) Web Application Development Platform 
 * Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 * http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.jdesigner.platform.cache.impl;

import java.lang.ref.SoftReference;
import java.lang.ref.WeakReference;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Properties;

import org.jdesigner.platform.cache.Cache;
import org.jdesigner.platform.cache.CacheException;

/**
 * MemoryCache
 * 
 * @author leesangboo
 * 
 */
public class MemoryCache implements Cache {

	private static final long serialVersionUID = 1L;

	public static final String CONFIG_REFERENCE_TYPE_KEY = "reference-type";

	private static final String WEAK = "WEAK";

	private static final String SOFT = "SOFT";

	private static final String STRONG = "STRONG";

	private String referanceType = "WEAK";

	public MemoryCache() {
		//
	}

	public MemoryCache(Properties configuration) {
		if (configuration != null) {
			String referanceType = configuration.getProperty(CONFIG_REFERENCE_TYPE_KEY);
			this.referanceType = referanceType;
		}
	}

	private Map cache = Collections.synchronizedMap(new HashMap());

	public Object get(String key) throws CacheException {
		Object value = null;
		Object ref = cache.get(key);
		if (ref != null) {
			if (ref instanceof StrongReference) {
				value = ((StrongReference) ref).get();
			} else if (ref instanceof SoftReference) {
				value = ((SoftReference) ref).get();
			} else if (ref instanceof WeakReference) {
				value = ((WeakReference) ref).get();
			}
		}
		return value;
	}

	public boolean hasValue(String key) throws CacheException {
		Object o = cache.get(key);
		if (o == null && !cache.containsKey(key)) {
			return false;
		} else {
			return true;
		}
	}

	public void put(String key, Object value) throws CacheException {
		Object reference = null;
		if (referanceType.equals(WEAK)) {
			reference = new WeakReference(value);
		} else if (referanceType.equals(SOFT)) {
			reference = new SoftReference(value);
		} else if (referanceType.equals(STRONG)) {
			reference = new StrongReference(value);
		}
		cache.put(key, reference);
		cache.put(key, value);
	}

	public void remove(String key) throws CacheException {
		cache.remove(key);
	}

	public void flush() throws CacheException {
		cache.clear();
	}

	public Map toMap() throws CacheException {
		return cache;
	}

	private static class StrongReference {
		private Object object;

		public StrongReference(Object object) {
			this.object = object;
		}

		public Object get() {
			return object;
		}
	}

}
