/*
 * JDesigner (R) Web Application Development Platform 
 * Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 * http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.core.threadlocal;

//import org.apache.log4j.MDC;

import java.util.Hashtable;

/**
 * <B>ThreadLocalProperties</B> <p> ThreadLocal 속성을 모든 서브 시스템에 필요한 매개 변수를 전달하는 방법에 사용하지 않고 설정할 수있습니다. </p>
 * 
 * @author SangBoo Lee
 */
public class ThreadLocalProperties {

	final static ThreadLocalProperties threadlocalproperties = new ThreadLocalProperties();

	static final int HT_SIZE = 7;

	private Object tl;

	private ThreadLocalProperties() {
		tl = new ThreadLocal();
	}

	/**
	 * Put a context value (the <code>o</code> parameter) as identified with the <code>key</code> parameter into the current thread's context map.
	 * 
	 * <p> If the current thread does not have a context map it is created as a side effect.
	 * 
	 */
	static public void put(String key, Object o) {
		//org.apache.log4j.Logger log = org.apache.log4j.Logger.getLogger(ThreadLocalProperties.class);
		//log.debug("putting " + o + " with key " + key);
		threadlocalproperties.put0(key, o);
		// Add to MDC of Log4J
		//MDC.put(key, o);
	}

	/**
	 * Get the context identified by the <code>key</code> parameter.
	 * 
	 * <p> This method has no side effects.
	 */
	static public Object get(String key) {
		return threadlocalproperties.get0(key);
	}

	/**
	 * Remove the the context identified by the <code>key</code> parameter.
	 * 
	 */
	static public void remove(String key) {
		threadlocalproperties.remove0(key);
	}

	/**
	 * Get the current thread's MDC as a hashtable. This method is intended to be used internally.
	 */
	public static Hashtable getContext() {
		return threadlocalproperties.getContext0();
	}

	private void put0(String key, Object o) {
		Hashtable ht = (Hashtable) ((ThreadLocal) tl).get();

		if (ht == null) {
			ht = new Hashtable(HT_SIZE);
			((ThreadLocal) tl).set(ht);
		}

		ht.put(key, o);
	}

	private Object get0(String key) {
		Hashtable ht = (Hashtable) ((ThreadLocal) tl).get();

		if ((ht != null) && (key != null)) {
			return ht.get(key);
		} else {
			return null;
		}
	}

	private void remove0(String key) {
		Hashtable ht = (Hashtable) ((ThreadLocal) tl).get();

		if (ht != null) {
			ht.remove(key);
		}
	}

	private Hashtable getContext0() {
		return (Hashtable) ((ThreadLocal) tl).get();
	}
}
