/*
 * JDesigner (R) Web Application Development Platform 
 * Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 * http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.jdesigner.platform.data;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

/**
 * Tree Node
 * 
 * @author SangBoo Lee
 * @since 1.0
 * 
 */
public class TreeNode {

	private String code;

	private String parentCode;

	private Map data;

	private int depth;

	private List nodes;

	/**
	 * TreeNode
	 * 
	 * @param index
	 * @param parent_index
	 * @param data
	 * @param url
	 */
	public TreeNode(String code, String parentCode, Map data) {
		this.code = code;
		this.parentCode = parentCode;
		this.data = data;

		depth = 0;
		nodes = new ArrayList();
	}

	/**
	 * 
	 * @return
	 */
	public int size() {
		return nodes.size();
	}

	/**
	 * 
	 * @param node
	 */
	public void add(TreeNode node) {
		if (code.equals(node.parentCode)) {
			node.depth = depth + 1;
			nodes.add(node);
			return;
		}

		Iterator iter = nodes.iterator();
		while (iter.hasNext()) {
			TreeNode iter_node = (TreeNode) iter.next();
			iter_node.add(node);
		}
	}

	/**
	 * 
	 * @return
	 */
	public Map getData() {
		return data;
	}

	/**
	 * 
	 * @param data
	 */
	public void setData(Map data) {
		this.data = data;
	}

	public String getCode() {
		return code;
	}

	public void setCode(String code) {
		this.code = code;
	}

	public String getParentCode() {
		return parentCode;
	}

	public void setParentCode(String parentCode) {
		this.parentCode = parentCode;
	}

	public int getDepth() {
		return depth;
	}

	public void setDepth(int depth) {
		this.depth = depth;
	}

	public List getNodes() {
		return nodes;
	}

	public void setNodes(List nodes) {
		this.nodes = nodes;
	}

	/**
	 * 
	 */
	public String toString() {
		StringBuffer sb = new StringBuffer();
		for (int i = 0, n = depth * 4; i < n; i++) {
			sb.append(" ");
		}
		sb.append("=" + data.toString());
		return sb.toString();
	}

}
