/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.jdesigner.platform.db.logger;

import java.util.Arrays;
import java.util.Map;
import java.util.SortedMap;
import java.util.TreeMap;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import org.jdesigner.platform.context.ApplicationConfigUtils;

/**
 * SQLLogger
 * 
 * @author leesangboo
 * 
 */
public class SQLLogger {

	private static final Log log = LogFactory.getLog(SQLLogger.class);

	private static final String NEW_LINE = System.getProperty("line.separator");

	private static final String SQL_LOGGING_KEY = "platform.db.sql.logging";

	private boolean isLogging = false;

	/**
	 * 
	 */
	public SQLLogger() {
		init(); //
	}

	/**
	 * 
	 * @param isLogging
	 */
	public SQLLogger(boolean isLogging) {
		this.isLogging = isLogging;
	}

	/**
	 * 초기화
	 * 
	 */
	private void init() {
		this.isLogging = ApplicationConfigUtils.getBoolean(SQL_LOGGING_KEY);
	}

	/**
	 * 
	 * @param sql
	 * @param params
	 */
	public void log(String sql, Object[] params, boolean inTransaction) {
		if (isLogging) {
			StringBuffer buffer = new StringBuffer();
			buffer.append(NEW_LINE + "------------------------------------------");
			buffer.append(NEW_LINE + " TX  = [").append(inTransaction).append("]");
			buffer.append(NEW_LINE + " SQL = [").append(sql).append("]");
			if (params == null) {
				buffer.append(NEW_LINE + "Parameters = []");
			} else {
				buffer.append(NEW_LINE + "Parameters = " + Arrays.asList(params));
			}
			buffer.append(NEW_LINE + "------------------------------------------");
			log.info(buffer.toString());
		}
	}

	/**
	 * 
	 * @param sql
	 * @param params
	 */
	public void log(String sql, Map params, boolean inTransaction) {
		if (isLogging) {
			StringBuffer buffer = new StringBuffer();
			buffer.append(NEW_LINE + "------------------------------------------");
			buffer.append(NEW_LINE + " TX  = [").append(inTransaction).append("]");
			buffer.append(NEW_LINE + " SQL = [").append(sql).append("]");
			if (params == null) {
				buffer.append(NEW_LINE + "Parameters = []");
			} else {
				SortedMap orderedParams = new TreeMap(params);
				buffer.append(NEW_LINE + "Parameters = " + orderedParams.toString());
			}
			buffer.append(NEW_LINE + "------------------------------------------");
			log.info(buffer.toString());
		}
	}

}
