/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.db.paging;

import java.util.List;
import java.util.Map;

import org.jdesigner.platform.db.parser.QueryParsingException;

/**
 * <B>PagingSQLHandler</B>
 * 
 * @author leesangboo
 * 
 */
public interface PagingSQLHandler {

	/**
	 * PAGING_ALIAS
	 */
	public static final String PAGING_ALIAS = "PAGING";

	/**
	 * ROWNUM_ALIAS
	 */
	public static final String ROWNUM_ALIAS = "RNUM";

	/**
	 * COUNT_ALIAS
	 */
	public static final String COUNT_ALIAS = "CNT";

	/**
	 * 페이징 SQL을 생성한다.
	 * 
	 * @param sql
	 * @param column
	 * @param desc
	 * @return
	 * @throws QueryParsingException
	 */
	public String generatePagingSQL(String sql, String column, boolean desc) throws QueryParsingException;

	/**
	 * 파라메터를 생성한다.
	 * 
	 * @param params
	 * @param start
	 * @param size
	 * @param column
	 * @param desc
	 * @return
	 * @throws QueryParsingException
	 */
	public Object[] createParameter(Object[] params, int start, int size) throws QueryParsingException;

	/**
	 * Named 페이징 SQL을 생성한다.
	 * 
	 * @param sql
	 * @param column
	 * @param desc
	 * @return
	 * @throws QueryParsingException
	 */
	public String generatePagingNamedSQL(String sql, String column, boolean desc) throws QueryParsingException;

	/**
	 * Named 파라메터를 생성한다.
	 * 
	 * @param params
	 * @param start
	 * @param size
	 * @return
	 * @throws QueryParsingException
	 */
	public Map createNamedParameter(Map params, int start, int size) throws QueryParsingException;

	/**
	 * 결과 리스트로 부터 카운트를 반환한다.
	 * 
	 * @param list
	 * @return
	 * @throws QueryParsingException
	 */
	public long getCountFromResult(List result) throws QueryParsingException;

}
