/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.db.provider;

import java.sql.Connection;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import org.jdesigner.platform.db.provider.rdbms.OracleRDBMSProvider;
import org.jdesigner.platform.db.vender.DatabaseName;
import org.jdesigner.platform.exception.DatabaseException;

/**
 * RDBMSProviderFactory
 * 
 * @author leesangboo
 * 
 */
public class RDBMSProviderFactory {

	private static final Log log = LogFactory.getLog(RDBMSProviderFactory.class);

	private static class RDBMSProviderFactoryHolder {
		static RDBMSProviderFactory instance = new RDBMSProviderFactory();
	}

	public static RDBMSProviderFactory getInstance() {
		return RDBMSProviderFactoryHolder.instance;
	}

	private Map cache = Collections.synchronizedMap(new HashMap());

	/**
	 * 
	 * @param dbName
	 * @return
	 * @throws DatabaseException
	 */
	public RDBMSProvider getRDBMSProvider(Connection connection) throws DatabaseException {
		try {
			String dbName = connection.getMetaData().getDatabaseProductName();
			if (!cache.containsKey(dbName)) {
				if (dbName.startsWith(DatabaseName.ORACLE)) {
					cache.put(dbName, new OracleRDBMSProvider());
				} else {
					throw new DatabaseException("Unsupport RDBMS provider this database type : databaseProductName=[" + dbName + "]");
				}
				log.info("Created RDBMS provider : databaseProductName=[" + dbName + "]");
			}
			return (RDBMSProvider) cache.get(dbName);
		} catch (Exception ex) {
			throw new DatabaseException("Cannot getting RDBMS provider.", ex);
		}
	}

}
