/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.db.provider.rdbms.oracle;

import org.jdesigner.platform.db.table.model.Column;
import org.jdesigner.platform.db.table.rdbms.JavaTypes;
import org.jdesigner.platform.db.table.rdbms.TableTypeMaker;

/**
 * OracleTypeMaker
 * 
 * @author leesangboo
 * 
 */
public class OracleTableTypeMaker implements TableTypeMaker {

	private static final String NUMBER = "NUMBER";

	private static final String VARCHAR2 = "VARCHAR2";

	private static final String CHAR = "CHAR";

	private static final String DATE = "DATE";

	private static final String LONG = "LONG";

	public String getType(Column column) {
		String javaType = JavaTypes.STRING;
		String columnTypeName = column.getTypeName();
		if (NUMBER.equals(columnTypeName) || LONG.equals(columnTypeName)) {
			javaType = (column.getDecimalDigits() == 0) ? JavaTypes.LONG : JavaTypes.DOUBLE;
		} else if (VARCHAR2.equals(columnTypeName)) {
			javaType = JavaTypes.STRING;
		} else if (CHAR.equals(columnTypeName)) {
			javaType = JavaTypes.STRING;
		} else if (DATE.equals(columnTypeName)) {
			javaType = JavaTypes.DATE;
		}
		return javaType;
	}

	public String[] getTypes(Column column) {
		String[] javaTypes = new String[] { JavaTypes.STRING };
		String columnTypeName = column.getTypeName();
		int columnDecimalDigits = column.getDecimalDigits();
		if (NUMBER.equals(columnTypeName)) {
			if (columnDecimalDigits == 0) {
				javaTypes = getNumberFamily(column.getColumnSize());
			} else {
				javaTypes = getDecimalNumberFamily(column.getColumnSize());
			}
		} else if (VARCHAR2.equals(columnTypeName)) {
			javaTypes = new String[] { JavaTypes.STRING };
		} else if (CHAR.equals(columnTypeName)) {
			javaTypes = new String[] { JavaTypes.CHAR, JavaTypes.CHAR_PRIMITIVE, JavaTypes.STRING };
		} else if (DATE.equals(columnTypeName)) {
			javaTypes = getDateFamily();
		}
		return javaTypes;
	}

	private String[] getDecimalNumberFamily(int columnSize) {
		String[] javaTypes = new String[] { JavaTypes.STRING };
		if (columnSize <= 37) {
			javaTypes = new String[] { JavaTypes.DOUBLE, JavaTypes.DOUBLE_PRIMITIVE, JavaTypes.FLOAT, JavaTypes.FLOAT_PRIMITIVE, JavaTypes.STRING };
		} else {
			javaTypes = new String[] { JavaTypes.DOUBLE, JavaTypes.DOUBLE_PRIMITIVE, JavaTypes.STRING };
		}
		return javaTypes;
	}

	private String[] getNumberFamily(int columnSize) {
		String[] javaTypes = new String[] { JavaTypes.STRING };
		if (columnSize >= 10) {
			javaTypes = new String[] { JavaTypes.LONG, JavaTypes.LONG_PRIMITIVE, JavaTypes.STRING };
		} else if (columnSize <= 9 && columnSize >= 5) {
			javaTypes = new String[] { JavaTypes.LONG, JavaTypes.LONG_PRIMITIVE, JavaTypes.INTEGER, JavaTypes.INTEGER_PRIMITIVE, JavaTypes.STRING };
		} else if (columnSize <= 4 && columnSize >= 2) {
			javaTypes = new String[] { JavaTypes.LONG, JavaTypes.LONG_PRIMITIVE, JavaTypes.INTEGER, JavaTypes.INTEGER_PRIMITIVE, JavaTypes.SHORT, JavaTypes.SHORT_PRIMITIVE, JavaTypes.STRING };
		} else if (columnSize <= 2) {
			javaTypes = new String[] { JavaTypes.LONG, JavaTypes.LONG_PRIMITIVE, JavaTypes.INTEGER, JavaTypes.INTEGER_PRIMITIVE, JavaTypes.SHORT, JavaTypes.SHORT_PRIMITIVE, JavaTypes.BYTE,
					JavaTypes.BYTE_PRIMITIVE, JavaTypes.STRING };
		}
		return javaTypes;
	}

	private String[] getDateFamily() {
		String[] javaTypes = new String[] { JavaTypes.DATE, JavaTypes.DATE_SQL, JavaTypes.STRING };
		return javaTypes;
	}

	/*
	 * private String[] getBooleanFamily() { String[] javaTypes = new String[] { JavaTypes.BOOLEAN, JavaTypes.BOOLEAN_PRIMITIVE, JavaTypes.STRING };
	 * return javaTypes; }
	 */
}
