/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.db.session;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import org.jdesigner.platform.db.transaction.TransactionUtils;

/**
 * SessionProvider
 * 
 * @author leesangboo
 * 
 */
public class SessionManager {

	private static final Log log = LogFactory.getLog(SessionManager.class);

	private static final String SESSION_SUFFIX = ".SESSION";

	/**
	 * Open new session.
	 * 
	 * @param persistenceId
	 * @param transactionType
	 * @param dataSourceJNDIName
	 */
	public void openSession(String persistenceId, int transactionType, String dataSourceJNDIName) {
		try {
			String sessionId = persistenceId + SESSION_SUFFIX;
			if (getOpenedSession(sessionId) == null) {
				log.info("Opening new session : sessionID=[" + sessionId + "], transactionType=[" + TransactionUtils.getTransactionType(transactionType) + "], dataSourceJNDIName=["
						+ dataSourceJNDIName + "]");
				//
				Session session = new Session(sessionId, dataSourceJNDIName, transactionType);
				SessionContext.addSession(sessionId, session);

			} else {
				throw new SessionException("Already opened session : sessionID=[" + persistenceId + SESSION_SUFFIX + "]");
			}
		} catch (Exception e) {
			throw new SessionException("Failed session manager for open session : " + e.getMessage(), e);
		}
	}

	/**
	 * Getting opened session.
	 * 
	 * @param persistenceId
	 * @return
	 */
	public Session getOpenedSession(String persistenceId) {
		return SessionContext.getSession(persistenceId + SESSION_SUFFIX);
	}

	/**
	 * Close session
	 * 
	 * @param persistenceId
	 */
	public void closeSession(String persistenceId) {
		try {
			SessionContext.removeSession(persistenceId + SESSION_SUFFIX);
		} catch (Exception e) {
			throw new SessionException("Failed session manager for close session : " + e.getMessage(), e);
		}
	}

}
