/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.jndi;

import java.util.HashMap;
import java.util.Map;

import javax.naming.Context;
import javax.naming.NamingException;
import javax.sql.DataSource;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * JDBC 데이터소스 서비스 로케이터
 * 
 * @author Administrator
 * 
 */
public class JDBCDataSourceServiceLocator {

	private static final Log log = LogFactory.getLog(JDBCDataSourceServiceLocator.class);

	private static class JDBCDataSourceServiceLocatorHolder {
		static JDBCDataSourceServiceLocator instance = new JDBCDataSourceServiceLocator();
	}

	public static JDBCDataSourceServiceLocator getInstance() {
		return JDBCDataSourceServiceLocatorHolder.instance;
	}

	/**
	 * DataSource를 반환한다.
	 * 
	 * @param dataSourceName
	 * @return
	 * @throws Exception
	 */
	public DataSource getDataSource(String dataSourceName) throws Exception {
		Context context = null;
		DataSource dataSource = null;
		try {
			if (cache.containsKey(dataSourceName)) {
				log.debug("Return cached DataSource : [" + dataSourceName + "]");
				dataSource = (DataSource) cache.get(dataSourceName);
			} else {
				log.debug("Create DataSource : [" + dataSourceName + "]");
				ContextFactory contextFactory = ContextFactory.getInstance();
				context = contextFactory.getContext();
				dataSource = (DataSource) context.lookup(dataSourceName);
				cache.put(dataSourceName, dataSource);
			}
		} catch (NamingException nex) {
			String msg = "Cannot get DataSource instance , invaild JNDI name [" + dataSourceName + "] : " + nex.getMessage();
			log.error(msg, nex);
			throw new ServiceLocatorException(msg, nex);
		} catch (Exception ex) {
			String msg = "Cannot get DataSource instance : " + ex.getMessage();
			log.error(msg, ex);
			throw new ServiceLocatorException(ex);
		}
		return dataSource;
	}

	private Map cache = new HashMap();

}