/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.scheduler.task;

import java.util.Enumeration;
import java.util.HashMap;
import java.util.Hashtable;
import java.util.Map;
import java.util.TimerTask;

import javax.servlet.ServletContext;

//import org.exolab.castor.mapping.MapItem;

/**
 * A task that can be scheduled for one-time or repeated execution by a <code>Scheduler</code>. The inherited run() method is called by a
 * <code>Timer</code> and must be overridden.
 * 
 * @author Pascal Essiembre
 * @version $Id: SchedulerTask.java,v 1.1 2010/04/08 05:42:09 love Exp $
 */
public abstract class SchedulerTask extends TimerTask {

	/** Parameters from scheduler configuration file */
	private Map initParameters = new HashMap();

	/** Application servlet context */
	private ServletContext servletContext;

	/**
	 * Constructor
	 */
	public SchedulerTask() {
		super();
	}

	/**
	 * Gets the servletConfig
	 * 
	 * @return Returns a ServletConfig
	 */
	public ServletContext getServletContext() {
		return servletContext;
	}

	/**
	 * Sets the servletConfig
	 * 
	 * @param servletConfig
	 *            The servletConfig to set
	 */
	public void setServletContext(ServletContext servletContext) {
		this.servletContext = servletContext;
	}

	/**
	 * Gets parameter value from scheduler configuration file, matching supplied parameter name.
	 * 
	 * @param paramName
	 *            name of parameter to get
	 * @return parameter value
	 * @since 1.1
	 */
	public String getInitParameter(String paramName) {
		return (String) initParameters.get(paramName);
	}

	/**
	 * Gets all parameter names defined in scheduler configuration file.
	 * 
	 * @return parameter names
	 * @since 1.1
	 */
	public Enumeration getInitParameterNames() {
		return ((Hashtable) initParameters).keys();
	}

	/**
	 * Sets initialization parameters for this scheduler task.
	 * 
	 * @param initParameters
	 *            initialization parameters
	 * @since 1.1
	 */
	public void setInitParameters(Map initParameters) {
		this.initParameters = initParameters;
	}

}