/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.web;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.struts.action.ActionErrors;
import org.apache.struts.action.ActionMessages;

import org.jdesigner.platform.context.ApplicationContext;
import org.jdesigner.platform.context.ApplicationContextFactory;

/**
 * <B>Action Bean</B>
 * 
 * </P>멀티 스레드 환경에서 안전한 스트러츠 확장 액션 빈입니다. </P>웹 컨트롤러 개발자는 반드시 이 클래스를 상속하여 액션 빈을 구현해야 합니다.
 * 
 * @author leesangboo
 * 
 */
abstract public class ActionBean extends BaseBean implements WebConstants {

	private static final long serialVersionUID = 423566340005056407L;

	/**
	 * ActionBean 생성자
	 */
	public ActionBean() {
		super();
	}

	/**
	 * ApplicationContext를 반환한다.
	 * 
	 * @return
	 */
	protected ApplicationContext getApplicationContext() {
		return ApplicationContextFactory.getInstance().getApplicationContext();
	}

	/**
	 * ActionContext를 반환한다.
	 * 
	 * @return
	 */
	protected ActionBeanContext getActionBeanContext() {
		return ActionBeanContext.getActionBeanContext();
	}

	/**
	 * ActionEvent를 반환한다.
	 * 
	 * @return
	 */
	protected ActionEvent getActionEvent() {
		return getActionBeanContext().getActionEvent();
	}

	/**
	 * ActionMessages 를 반환한다.
	 * 
	 * @return
	 */
	protected ActionMessages getActionMessages() {
		return getActionBeanContext().getActionMessages();
	}

	/**
	 * ActionErrors 를 반환한다.
	 * 
	 * @return
	 */
	protected ActionErrors getActionErrors() {
		return getActionBeanContext().getActionErrors();
	}

	/**
	 * HttpServletRequest 를 반환한다.
	 * 
	 * @return
	 */
	protected HttpServletRequest getRequest() {
		return getActionBeanContext().getRequest();
	}

	/**
	 * HttpServletResponse 를 반환한다.
	 * 
	 * @return
	 */
	protected HttpServletResponse getResponse() {
		return getActionBeanContext().getResponse();
	}

}
