/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.web;

import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.io.PrintWriter;
import java.math.BigDecimal;
import java.math.BigInteger;
import java.net.MalformedURLException;
import java.net.URL;

import javax.servlet.ServletConfig;
import javax.servlet.ServletException;
import javax.servlet.UnavailableException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.beanutils.ConvertUtils;
import org.apache.commons.digester.Digester;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.config.ModuleConfig;
import org.apache.struts.util.ModuleUtils;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;

import org.jdesigner.platform.context.ApplicationContextFactory;
import org.jdesigner.platform.util.StringUtils;
import org.jdesigner.platform.web.converter.BigDecimalConverter;
import org.jdesigner.platform.web.converter.BigIntegerConverter;
import org.jdesigner.platform.web.converter.DateConverter;
import org.jdesigner.platform.web.converter.DoubleConverter;
import org.jdesigner.platform.web.converter.FloatConverter;
import org.jdesigner.platform.web.converter.IntegerConverter;
import org.jdesigner.platform.web.converter.LongConverter;
import org.jdesigner.platform.web.converter.ShortConverter;
import org.jdesigner.platform.web.converter.SqlDateConverter;
import org.jdesigner.platform.web.converter.SqlTimeConverter;
import org.jdesigner.platform.web.converter.SqlTimestampConverter;
import org.jdesigner.platform.web.converter.StringConverter;

/**
 * <B>Action Servlet</B>
 * 
 * @author leesangboo
 * 
 */
public class ActionServlet extends org.apache.struts.action.ActionServlet {

	protected static Log log = LogFactory.getLog(ActionServlet.class);

	private static final long serialVersionUID = 1L;

	private static final String DEFAULT_RELOAD_URL = "/admin/struts/reload.do";

	/**
	 * ActionServlet 생성자
	 */
	public ActionServlet() {
		super();
	}

	/**
	 * <P> ServletMapping을 반환한다. </P>
	 * 
	 * @return
	 */
	public String getServletMapping() {
		return this.servletMapping;
	}

	/**
	 * <P> 시스템에서 사용되는 자원을 초기화한후 다시 읽어 들인다. </P> <P> 이 부분에서 각 자원에 대한 사항 (상수 정의 , 캐싱 , 싱글턴 등 )을 초기화를 한다./P>
	 * 
	 * @param isFisrtLoad
	 */
	public void initResources(boolean isFisrtLoad) {
		//
	}

	/**
	 * <P> Action Servlet 초기화 </P>
	 * 
	 * @throws ServletException
	 *             오류발생시
	 */
	public void init() throws ServletException {
		log.info("ActionServlet initializing...");
		initResources(true);
		super.init();
		log.info("Completed initializing Apache's Struts ActionServlet extension (1.3.10) for context '" + super.getServletContext().getServletContextName() + "'");
	}

	/**
	 * <P> Action Servlet 다시 초기화 </P>
	 * 
	 * @throws ServletException
	 *             오류발생시
	 */
	public void initReload() throws ServletException {
		log.info("ActionServlet reloading...");
		initResources(false);
		super.init();
		log.info("ActionServlet reload.");
	}

	/*
	 * 
	 * @seeorg.apache.struts.action.ActionServlet#process(javax.servlet.http. HttpServletRequest, javax.servlet.http.HttpServletResponse)
	 */
	protected void process(HttpServletRequest req, HttpServletResponse res) throws IOException, ServletException {

		String uri = req.getRequestURI();

		String reloadUrl = getServletConfig().getInitParameter("config.reload.url");
		if (reloadUrl == null) {
			log.warn("Struts action reload for pararmeter [config.reload.url] set up. use default : " + DEFAULT_RELOAD_URL);
			reloadUrl = DEFAULT_RELOAD_URL;
		}

		if (uri.indexOf(reloadUrl) != -1) {

			this.initReload(); //

			ModuleUtils.getInstance().selectModule(req, getServletContext());
			ModuleConfig config = getModuleConfig(req);
			getRequestProcessor(config).init(this, config);

			res.setContentType("text/html;charset=UTF-8");
			PrintWriter out = res.getWriter();
			req.setCharacterEncoding("UTF-8");
			out.println("ActionServlet is reloaded successfully.");

		} else {
			super.process(req, res);
		}
	}

	/**
	 * <p> Initialize other global characteristics of the controller servlet. </p>
	 * 
	 * @exception ServletException
	 *                if we cannot initialize these resources
	 */
	protected void initOther() throws ServletException {

		super.initOther();
		this.initXMLConfigFiles(getServletConfig());
		this.initParameterFieldConverters();

	}

	/**
	 * <p> Parses one module config file. </p>
	 * 
	 * @param digester
	 *            Digester instance that does the parsing
	 * @param path
	 *            The path to the config file to parse.
	 * 
	 * @throws UnavailableException
	 *             if file cannot be read or parsed
	 * @since Struts 1.2
	 */
	protected void parseModuleConfigFile(Digester digester, String path) throws UnavailableException {

		InputStream input = null;

		try {
			URL url = (new File(path).toURI()).toURL();
			if (url == null) {
				String msg = "Unable to configuration file path : " + path;
				log.error(msg);
				throw new UnavailableException(msg);
			}

			InputSource is = new InputSource(url.toExternalForm());
			input = url.openStream();
			is.setByteStream(input);
			digester.parse(is);

		} catch (MalformedURLException e) {
			handleConfigException(path, e);
		} catch (IOException e) {
			handleConfigException(path, e);
		} catch (SAXException e) {
			handleConfigException(path, e);
		} finally {
			if (input != null) {
				try {
					input.close();
				} catch (IOException e) {
					throw new UnavailableException(e.getMessage());
				}
			}
		}

	}

	/**
	 * <p> Simplifies exception handling in the <code>parseModuleConfigFile</code> method. <p>
	 * 
	 * @param path
	 * @param e
	 * @throws UnavailableException
	 *             as a wrapper around Exception
	 */
	private void handleConfigException(String path, Exception e) throws UnavailableException {
		String msg = "Struts configuration exception : " + e.getMessage();
		log.error(msg, e);
		throw new UnavailableException(msg);
	}

	/**
	 * <P> Struts XML 설정 파일을 초기화한다. </P>
	 * 
	 * @throws ServletException
	 */
	private void initXMLConfigFiles(ServletConfig servletConfig) throws ServletException {
		try {

			String configParam = getServletConfig().getInitParameter("config");
			if (configParam != null) {
				log.info("Using default struts configuration file loading option.");
				return;
			}

			log.info("Loading struts configuration files using pattern matching, use the option.");

			ApplicationContextFactory factory = ApplicationContextFactory.getInstance();
			String appPath = factory.getApplicationContext().getAppPath();

			String configXmlBasePath = getServletConfig().getInitParameter("config.xml.base.path");
			String configXmlPattern = getServletConfig().getInitParameter("config.xml.pattern");

			if (StringUtils.isEmpty(configXmlBasePath) || StringUtils.isEmpty(configXmlPattern)) {
				String msg = "ActionServlet initialization parameters [config.xml.base.path] or [config.xml.pattern], please set up.";
				log.error(msg);
				throw new UnavailableException(msg);
			}

			log.info("Struts configuration info : path=[" + configXmlBasePath + "] , pattern=[" + configXmlPattern + "]");

			String[] pathArray = XMLFileReader.getAllFilePathArray(appPath, configXmlBasePath, configXmlPattern);
			if (pathArray != null && pathArray.length > 0) {
				String commaCombinedPath = "";
				for (int i = 0, size = pathArray.length; i < size; i++) {
					commaCombinedPath += "," + pathArray[i];
				}
				super.config = commaCombinedPath.substring(1);
				log.info("Loaded struts configuration files : [" + super.config + "]");
			} else {
				String msg = "Not found struts configuration files.";
				log.error(msg);
				throw new UnavailableException(msg);
			}

		} catch (Exception e) {
			throw new ServletException(e);
		}
	}

	/**
	 * <P> 파라메터 필드 타입 컨버터를 초기화한다. </P>
	 * 
	 * @throws ServletException
	 */
	private void initParameterFieldConverters() throws ServletException {

		ConvertUtils.deregister();

		ConvertUtils.register(new StringConverter(null), String.class);

		ConvertUtils.register(new IntegerConverter(null), int.class);
		ConvertUtils.register(new FloatConverter(null), float.class);
		ConvertUtils.register(new LongConverter(null), long.class);
		ConvertUtils.register(new DoubleConverter(null), double.class);
		ConvertUtils.register(new ShortConverter(null), short.class);

		ConvertUtils.register(new BigDecimalConverter(null), BigDecimal.class);
		ConvertUtils.register(new BigIntegerConverter(null), BigInteger.class);
		ConvertUtils.register(new DoubleConverter(null), Double.class);
		ConvertUtils.register(new FloatConverter(null), Float.class);
		ConvertUtils.register(new IntegerConverter(null), Integer.class);
		ConvertUtils.register(new LongConverter(null), Long.class);
		ConvertUtils.register(new ShortConverter(null), Short.class);

		ConvertUtils.register(new DateConverter(null), java.util.Date.class);
		ConvertUtils.register(new SqlDateConverter(null), java.sql.Date.class);
		ConvertUtils.register(new SqlTimeConverter(null), java.sql.Time.class);
		ConvertUtils.register(new SqlTimestampConverter(null), java.sql.Timestamp.class);

		log.info("Regist parameter/bean field converters.");
	}

}
