/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.jdesigner.platform.web.filter;

import java.io.IOException;

import javax.servlet.Filter;
import javax.servlet.FilterChain;
import javax.servlet.FilterConfig;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * Filter that compresses output with gzip (assuming that browser supports gzip). Code from <a
 * href="http://www.onjava.com/pub/a/onjava/2003/11/19/filters.html"> http://www.onjava.com/pub/a/onjava/2003/11/19/filters.html</a>.
 * 
 * 
 * @web.filter name="compressionFilter"
 * 
 * @web.filter-mapping url-pattern="*.do"
 */
public class GZIPFilter implements Filter {
	private static Log log = LogFactory.getLog(GZIPFilter.class);

	public void doFilter(ServletRequest req, ServletResponse res, FilterChain chain) throws IOException, ServletException {
		if (req instanceof HttpServletRequest) {
			HttpServletRequest request = (HttpServletRequest) req;
			HttpServletResponse response = (HttpServletResponse) res;

			if (isGZIPSupported(request)) {
				if (log.isDebugEnabled()) {
					log.debug("GZIP supported, compressing response");
				}

				GZIPResponseWrapper wrappedResponse = new GZIPResponseWrapper(response);

				chain.doFilter(req, wrappedResponse);
				wrappedResponse.finishResponse();

				return;
			}

			chain.doFilter(req, res);
		}
	}

	/**
	 * Convenience method to test for GZIP cababilities
	 * 
	 * @param req
	 *            The current user request
	 * @return boolean indicating GZIP support
	 */
	private boolean isGZIPSupported(HttpServletRequest req) {
		String browserEncodings = req.getHeader("accept-encoding");
		boolean supported = ((browserEncodings != null) && (browserEncodings.indexOf("gzip") != -1));
		return supported;

		// String userAgent = req.getHeader("user-agent");

		// if (userAgent.startsWith("httpunit")) {
		// if (log.isDebugEnabled()) {
		// log.debug("httpunit detected, disabling filter...");
		// }
		//
		// return false;
		// } else {
		// return supported;
		// }
	}

	public void init(FilterConfig filterConfig) {
		// no action here
	}

	public void destroy() {
		// no action here
	}
}