/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.jdesigner.platform.web.filter;

import java.io.IOException;
import java.util.Locale;

import javax.servlet.Filter;
import javax.servlet.FilterChain;
import javax.servlet.FilterConfig;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.Globals;

import org.jdesigner.platform.core.threadlocal.ThreadLocalProperties;
import org.jdesigner.platform.util.StringUtils;
import org.jdesigner.platform.web.WebUtils;
import org.jdesigner.platform.web.locale.LocaleHandler;

/**
 * <B>LocaleFilter</B>
 * 
 * @author leesangboo
 * 
 */
public class LocaleFilter implements Filter {

	private static final Log log = LogFactory.getLog(LocaleFilter.class);

	private String parameter;

	/*
	 * (non-Javadoc)
	 * 
	 * @see javax.servlet.Filter#init(javax.servlet.FilterConfig)
	 */
	public void init(FilterConfig config) throws ServletException {
		this.parameter = config.getInitParameter("parameter");
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see javax.servlet.Filter#destroy()
	 */
	public void destroy() {
		this.parameter = null;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see javax.servlet.Filter#doFilter(javax.servlet.ServletRequest, javax.servlet.ServletResponse, javax.servlet.FilterChain)
	 */
	public void doFilter(ServletRequest srequest, ServletResponse sresponse, FilterChain chain) throws IOException, ServletException {
		HttpServletRequest request = (HttpServletRequest) srequest;
		HttpServletResponse response = (HttpServletResponse) sresponse;
		String locale_parameter = request.getParameter(parameter);

		if (StringUtils.isNotEmpty(locale_parameter)) {
			LocaleHandler lh = WebUtils.getLocaleHandler();
			lh.setUserLocale(request, response, WebUtils.stringToLocale(locale_parameter));
			log.debug("LocaleFilter : setUserLocale=" + locale_parameter);
		}

		//
		Locale locale = (Locale) request.getSession().getAttribute(Globals.LOCALE_KEY);
		if (locale != null) {
			log.debug("Locale set thread local properties.");
			ThreadLocalProperties.put(Globals.LOCALE_KEY, locale);
		}

		//
		chain.doFilter(srequest, sresponse);
	}

}
