/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.jdesigner.platform.web.grid;

import java.lang.reflect.Method;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.jsp.JspException;

import org.apache.commons.lang.StringEscapeUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.taglib.TagUtils;

import org.jdesigner.platform.util.ReflectionUtils;

/**
 * JSONGridResultWriter
 * 
 * @author leesangboo
 * 
 */
public class JSONResultWriter {

	private static final Log log = LogFactory.getLog(JSONResultWriter.class);

	private boolean debug = false;

	private HttpServletRequest request;

	private HttpServletResponse response;

	/**
	 * JSONGridResultWriter
	 * 
	 * @param request
	 * @param response
	 */
	public JSONResultWriter(HttpServletRequest request, HttpServletResponse response, boolean debug) {
		this.request = request;
		this.response = response;
		this.debug = debug;
	}

	/**
	 * Print json string in jsp
	 * 
	 * @throws Exception
	 */
	public void write() throws Exception {
		try {
			String json = getString();
			try {
				// response.setContentType("text/x-json");
				response.getOutputStream().print(json);
			} catch (java.lang.IllegalStateException ie) {
				response.getWriter().print(json);
			}
		} catch (Exception ex) {
			log.error("Grid JSON result writing error : " + ex.getMessage(), ex);
			throw ex;
		}
	}

	/**
	 * getting JSON String
	 * 
	 * @throws Exception
	 */
	public String getString() throws Exception {

		//
		String name = request.getParameter("name");
		String property = request.getParameter("property");
		String page = request.getParameter("page");
		String perpage = request.getParameter("perpage");

		try {

			//
			log.debug("Params : name=" + name + ", property=" + property + ", page=" + page + ", perpage=" + perpage);

			//
			StringBuffer buffer = new StringBuffer();
			Grid grid = null;

			Object actionBean = request.getAttribute(name);
			if (actionBean == null) {
				throw new Exception("Not found ActionBean in request : [" + name + "]");
			}
			String methodName = "get" + property.substring(0, 1).toUpperCase() + property.substring(1);
			Method method = actionBean.getClass().getMethod(methodName, null);
			grid = (Grid) ReflectionUtils.invokeMethod(method, actionBean);

			//
			if (grid != null) {

				buffer.append("{");
				buffer.append("\"page\"    : \"" + page + "\",");
				buffer.append("\"perpage\" : \"" + perpage + "\",");
				buffer.append("\"total\"   : \"" + grid.getCount() + "\",");
				buffer.append("\"data\"    : [");

				//
				if (grid.getList() != null) {

					List columnNameList = new ArrayList();
					Map baseColumnMap = (Map) grid.getList().get(0);
					Iterator baseColumns = baseColumnMap.keySet().iterator();
					while (baseColumns.hasNext()) {
						String key = (String) baseColumns.next();
						columnNameList.add(key);
					}

					//
					Map appendColumnMap = grid.getColumns();
					if (appendColumnMap != null && !appendColumnMap.isEmpty()) {
						Iterator appendColumns = appendColumnMap.keySet().iterator();
						while (appendColumns.hasNext()) {
							String key = (String) appendColumns.next();
							columnNameList.add(key);
						}
					}

					//
					List dataList = grid.getList();
					if (dataList != null && dataList.size() > 0) {
						Map columns = grid.getColumns();
						Map dacorators = grid.getDecorators();
						for (int i = 0; i < dataList.size(); i++) { // rows
							Map data = (Map) dataList.get(i);
							buffer.append("{");

							for (int j = 0; j < columnNameList.size(); j++) { // columns
								String columnName = (String) columnNameList.get(j);
								// Decorator
								if (dacorators != null && dacorators.containsKey(columnName)) {
									Decorator decorator = (Decorator) dacorators.get(columnName);
									buffer.append("\"").append(columnName).append("\"").append(":").append("\"").append(decorator.decorate(grid, data, j, formatValue(data.get(columnName)))).append(
											"\"");
									// Column
								} else if (columns != null && columns.containsKey(columnName)) {
									Column column = (Column) columns.get(columnName);
									buffer.append("\"").append(columnName).append("\"").append(":").append("\"").append(column.append(grid, data, j, formatValue(data.get(columnName)))).append("\"");
								} else {
									buffer.append("\"").append(columnName).append("\"").append(":").append("\"").append(formatValue(data.get(columnName))).append("\"");
								}
								if (j != (columnNameList.size() - 1)) {
									buffer.append(",");
								}
							}

							buffer.append("}");
							if (i != (dataList.size() - 1)) {
								buffer.append(",");
							}
						}

					} else { // grid list check
						log.debug("Grid list data is null.");
					}

				}

			} else { // grid object check
				log.warn("Grid Object is null.");
			}

			buffer.append("]");

			buffer.append("}");

			if (debug) {
				log.info("Grid JSON String = " + buffer.toString());
			}

			return buffer.toString();

			//
		} catch (Exception ex) {
			log.error("Grid JSON result string getting error : " + ex.getMessage(), ex);
			throw ex;
		}
	}

	/**
	 * Sync Struts Data Format
	 * 
	 * @param value
	 * @return
	 * @throws JspException
	 */
	private String formatValue(Object value) throws JspException {
		if (value == null) {
			return "";
		}
		String new_value = StringEscapeUtils.escapeJavaScript(value.toString());
		return TagUtils.getInstance().filter(new_value);
	}

}
