/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.jdesigner.platform.web.locale;

import java.util.Locale;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.Globals;

import org.jdesigner.platform.context.ApplicationConfigUtils;
import org.jdesigner.platform.web.WebUtils;

/**
 * 
 * @author leesangboo
 * 
 */
abstract class BaseLocaleHandler {

	private static final Log log = LogFactory.getLog(BaseLocaleHandler.class);

	private static final String DEFAULT_LOCALE_KEY = "platform.web.i18n.locale";

	/**
	 * 사용자의 기본 지역(Locale)을 설정한다.
	 * 
	 * @param request
	 */
	public Locale getDefaultUserLocale() {
		return WebUtils.stringToLocale(ApplicationConfigUtils.getProperty(DEFAULT_LOCALE_KEY));
	}

	/**
	 * 사용자의 지역(Locale)을 반환한다.
	 * 
	 * @param request
	 * @return
	 */
	public Locale getUserLocale(HttpServletRequest request, HttpServletResponse response) {
		try {
			HttpSession session = request.getSession();
			Locale locale = (Locale) session.getAttribute(Globals.LOCALE_KEY);
			// 1.Check current session
			if (locale == null) {
				// 2.Check tech store
				locale = getTechLocale(request, response);
				setUserLocale(request, response, locale);
				if (locale == null) {
					locale = getDefaultUserLocale();
					log.info("Not found user's locale, Application has been set to the default locale : locale=[" + locale.toString() + "]");
					setUserLocale(request, response, locale);
				}
			}
			return locale;
		} catch (Exception ex) {
			log.error("Error getting user locale : " + ex.getMessage(), ex);
			return getDefaultUserLocale();
		}
	}

	/**
	 * 사용자의 지역(Locale)을 설정한다.
	 * 
	 * @param request
	 * @param locale
	 */
	public void setUserLocale(HttpServletRequest request, HttpServletResponse response, Locale inLocale) {
		try {
			setTechLocale(request, response, inLocale);
			request.getSession().setAttribute(Globals.LOCALE_KEY, inLocale);
		} catch (Exception ex) {
			log.error("Error setting user locale : " + ex.getMessage(), ex);
		}
	}

	/**
	 * 
	 * @throws Exception
	 */
	public abstract void setTechLocale(HttpServletRequest request, HttpServletResponse response, Locale inLocale) throws Exception;

	/**
	 * 
	 * @param request
	 * @param response
	 * @throws Exception
	 */
	public abstract Locale getTechLocale(HttpServletRequest request, HttpServletResponse response) throws Exception;

}
