/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.jdesigner.platform.web.locale;

import java.util.Locale;

import javax.servlet.http.Cookie;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import org.jdesigner.platform.web.WebUtils;

/**
 * CookieLocaleHandler
 * 
 * @author leesangboo
 * 
 */
public class CookieLocaleHandler extends BaseLocaleHandler implements LocaleHandler {

	private static final Log log = LogFactory.getLog(CookieLocaleHandler.class);

	private static final String COOKIE_NAME = "_user_client_locale"; //

	private static final String COOKIE_PATH = "/"; //

	private static final int COOKIE_MAX_AGE = 365 * 24 * 60 * 60; // 1year

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesigner.platform.web.locale.BaseLocaleHandler#setTechLocale(javax .servlet.http.HttpServletRequest,
	 * javax.servlet.http.HttpServletResponse, java.util.Locale)
	 */
	public void setTechLocale(HttpServletRequest request, HttpServletResponse response, Locale inLocale) throws Exception {
		//

		try {
			if (inLocale != null) {
				log.info("Locale set in http cookie : locale=[" + inLocale.toString() + "]");
				Cookie cookie = new Cookie(COOKIE_NAME, inLocale.toString());
				cookie.setPath(COOKIE_PATH);
				cookie.setMaxAge(COOKIE_MAX_AGE);
				response.addCookie(cookie);
			} else {
				//
			}
		} catch (Exception ex) {
			log.error("Error setting locale in http cookie.");
		}

	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesigner.platform.web.locale.BaseLocaleHandler#getTechLocale(javax .servlet.http.HttpServletRequest,
	 * javax.servlet.http.HttpServletResponse)
	 */
	public Locale getTechLocale(HttpServletRequest request, HttpServletResponse response) throws Exception {
		Locale locale = null;
		Cookie cookies[] = request.getCookies();
		Cookie myCookie = null;
		if (cookies != null) {
			for (int i = 0; i < cookies.length; i++) {
				if (cookies[i].getName().equals(COOKIE_NAME)) {
					myCookie = cookies[i];
					break;
				}
			}
		}
		if (myCookie != null) {
			String cookieLocale = myCookie.getValue();
			locale = WebUtils.stringToLocale(cookieLocale);
			log.info("Find locale in client browser : locale=[" + locale.toString() + "]");
		}
		return locale;
	}

}
