/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.web.tag.ui;

import java.lang.reflect.Method;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import net.sf.json.JSONObject;

import org.jdesigner.platform.util.ReflectionUtils;
import org.jdesigner.platform.web.table.Table;
import org.jdesigner.platform.web.tag.ui.template.UITemplateModel;

/**
 * TableTag
 * 
 * @author leesangboo
 * 
 */
public class TableTag extends BaseUITag {

	private static final long serialVersionUID = 1L;

	private static final String TEMPLATE_PATH = "table.ftl";

	private String name;

	private String property;

	private String url;

	private String parameter;

	private int page;

	private int perPage;

	private String perPageOptions;

	private boolean alternateRows;

	private boolean pagination;

	private boolean serverSort;

	private String defaultSort;

	private boolean defaultDesc;

	private boolean showHeader;

	private boolean sortHeader;

	private boolean resizeColumns;

	private boolean multipleSelection;

	private boolean filterHide;

	private String filterHideCls;

	private String filterSelectedCls;

	private String width;

	private String height;

	private String lineHeight;

	private boolean autoLoad;

	private boolean resizer;

	private String mouseoverFunction;

	private String mouseoutFunction;

	private String clickFunction;

	private String dbclickFunction;

	private String loaddataFunction;

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesigner.platform.web.tag.ui.BaseUITag#getStartModel()
	 */
	public UITemplateModel getStartModel() throws Exception {

		//
		UITemplateModel model = new UITemplateModel(TEMPLATE_PATH);

		model.put("id", id);
		model.put("name", name);
		model.put("property", property);
		if (url.startsWith("/")) {
			model.put("url", getRequest().getContextPath() + url);
		} else {
			model.put("url", url);
		}
		model.put("parameter", parameter, "");
		model.put("page", page, 1);
		model.put("perPage", perPage, 10);
		model.put("perPageOptions", perPageOptions, "[5, 10, 15, 20, 30, 50, 100, 200]");
		model.put("alternateRows", alternateRows);
		model.put("pagination", pagination);
		model.put("serverSort", serverSort);
		model.put("defaultSort", defaultSort);
		model.put("defaultDesc", defaultDesc);
		model.put("showHeader", showHeader);
		model.put("sortHeader", sortHeader);
		model.put("resizeColumns", resizeColumns);
		model.put("multipleSelection", multipleSelection);
		model.put("filterHide", filterHide);
		model.put("filterHideCls", filterHideCls, "hide");
		model.put("filterSelectedCls", filterSelectedCls, "filter");
		model.put("width", width, "auto");
		model.put("height", height, "200");
		model.put("lineHeight", lineHeight, "20");
		model.put("autoLoad", autoLoad);
		model.put("resizer", resizer);

		model.put("mouseoverFunction", mouseoverFunction);
		model.put("mouseoutFunction", mouseoutFunction);
		model.put("clickFunction", clickFunction);
		model.put("dbclickFunction", dbclickFunction);
		model.put("loaddataFunction", loaddataFunction);

		return model;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.jdesigner.platform.web.tag.ui.BaseUITag#getEndModel()
	 */
	public UITemplateModel getEndModel() throws Exception {

		UITemplateModel model = new UITemplateModel(TEMPLATE_PATH);

		// GRID COLUMN MODEL
		String gridId = id;
		List columnModelList = (List) pageContext.getAttribute(TagConstants.TABLE_COLUMN_MODEL_KEY + "_" + gridId);
		if (columnModelList == null) {
			throw new Exception("Table column model is null.");
		}
		model.put("columnModelList", columnModelList);

		//
		Object actionBean = super.getRequest().getAttribute(name);
		if (actionBean == null) {
			throw new Exception("Not found ActionBean in request : [" + name + "]");
		}
		String methodName = "get" + property.substring(0, 1).toUpperCase() + property.substring(1);
		Method method = actionBean.getClass().getMethod(methodName, null);
		Table table = (Table) ReflectionUtils.invokeMethod(method, actionBean);
		List dataModelList = new ArrayList();
		for (int i = 0; i < table.size(); i++) {
			Map map = (Map) table.get(i);
			JSONObject json = JSONObject.fromObject(map);
			map.put("json", json.toString());
			map.put("row", new Integer((i + 1)));
			dataModelList.add(map);
		}
		model.put("dataModelList", dataModelList);

		return model;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see oracle.erp.common.web.taglib.BaseUITag#reset()
	 */
	public void reset() {
		name = "";
		property = "";
		url = "";
		parameter = "";
		page = 1;
		perPage = 10;
		perPageOptions = "[5, 10, 15, 20, 30, 50, 100, 200]";
		pagination = false;
		alternateRows = true;
		serverSort = false;
		defaultSort = "";
		defaultDesc = false;
		showHeader = true;
		sortHeader = true;
		resizeColumns = true;
		multipleSelection = false;
		filterHide = true;
		filterSelectedCls = "";
		width = "auto";
		height = "200";
		lineHeight = "20";
		autoLoad = false;
		resizer = false;

		mouseoverFunction = "";
		mouseoutFunction = "";
		clickFunction = "";
		dbclickFunction = "";
		loaddataFunction = "";
	}

	public boolean isAutoLoad() {
		return autoLoad;
	}

	public void setAutoLoad(boolean autoLoad) {
		this.autoLoad = autoLoad;
	}

	public String getClickFunction() {
		return clickFunction;
	}

	public void setClickFunction(String clickFunction) {
		this.clickFunction = clickFunction;
	}

	public String getDbclickFunction() {
		return dbclickFunction;
	}

	public void setDbclickFunction(String dbclickFunction) {
		this.dbclickFunction = dbclickFunction;
	}

	public boolean isFilterHide() {
		return filterHide;
	}

	public void setFilterHide(boolean filterHide) {
		this.filterHide = filterHide;
	}

	public String getFilterSelectedCls() {
		return filterSelectedCls;
	}

	public void setFilterSelectedCls(String filterSelectedCls) {
		this.filterSelectedCls = filterSelectedCls;
	}

	public String getHeight() {
		return height;
	}

	public void setHeight(String height) {
		this.height = height;
	}

	public String getLineHeight() {
		return lineHeight;
	}

	public void setLineHeight(String lineHeight) {
		this.lineHeight = lineHeight;
	}

	public boolean isMultipleSelection() {
		return multipleSelection;
	}

	public void setMultipleSelection(boolean multipleSelection) {
		this.multipleSelection = multipleSelection;
	}

	public int getPage() {
		return page;
	}

	public void setPage(int page) {
		this.page = page;
	}

	public boolean isPagination() {
		return pagination;
	}

	public void setPagination(boolean pagination) {
		this.pagination = pagination;
	}

	public int getPerPage() {
		return perPage;
	}

	public void setPerPage(int perPage) {
		this.perPage = perPage;
	}

	public String getPerPageOptions() {
		return perPageOptions;
	}

	public void setPerPageOptions(String perPageOptions) {
		this.perPageOptions = perPageOptions;
	}

	public boolean isResizeColumns() {
		return resizeColumns;
	}

	public void setResizeColumns(boolean resizeColumns) {
		this.resizeColumns = resizeColumns;
	}

	public boolean isServerSort() {
		return serverSort;
	}

	public void setServerSort(boolean serverSort) {
		this.serverSort = serverSort;
	}

	public boolean isShowHeader() {
		return showHeader;
	}

	public void setShowHeader(boolean showHeader) {
		this.showHeader = showHeader;
	}

	public boolean isSortHeader() {
		return sortHeader;
	}

	public void setSortHeader(boolean sortHeader) {
		this.sortHeader = sortHeader;
	}

	public String getUrl() {
		return url;
	}

	public void setUrl(String url) {
		this.url = url;
	}

	public String getWidth() {
		return width;
	}

	public void setWidth(String width) {
		this.width = width;
	}

	public boolean isAlternateRows() {
		return alternateRows;
	}

	public void setAlternateRows(boolean alternateRows) {
		this.alternateRows = alternateRows;
	}

	public String getFilterHideCls() {
		return filterHideCls;
	}

	public void setFilterHideCls(String filterHideCls) {
		this.filterHideCls = filterHideCls;
	}

	public boolean isDefaultDesc() {
		return defaultDesc;
	}

	public void setDefaultDesc(boolean defaultDesc) {
		this.defaultDesc = defaultDesc;
	}

	public String getDefaultSort() {
		return defaultSort;
	}

	public void setDefaultSort(String defaultSort) {
		this.defaultSort = defaultSort;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public String getProperty() {
		return property;
	}

	public void setProperty(String property) {
		this.property = property;
	}

	public boolean isResizer() {
		return resizer;
	}

	public void setResizer(boolean resizer) {
		this.resizer = resizer;
	}

	public String getParameter() {
		return parameter;
	}

	public void setParameter(String parameter) {
		this.parameter = parameter;
	}

	public String getLoaddataFunction() {
		return loaddataFunction;
	}

	public void setLoaddataFunction(String loaddataFunction) {
		this.loaddataFunction = loaddataFunction;
	}

	public String getMouseoverFunction() {
		return mouseoverFunction;
	}

	public void setMouseoverFunction(String mouseoverFunction) {
		this.mouseoverFunction = mouseoverFunction;
	}

	public String getMouseoutFunction() {
		return mouseoutFunction;
	}

	public void setMouseoutFunction(String mouseoutFunction) {
		this.mouseoutFunction = mouseoutFunction;
	}

}
