/*
 *  JDesigner (R) Web Application Development Platform 
 *  Copyright (C) 2010 JDesigner / SangBoo Lee (leesangboo@gmail.com)
 * 
 *  http://www.jdesigner.org/
 *  
 *  Please contact if you require licensing terms other
 *  than GPL-3 for this software.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.jdesigner.platform.web.tag.ui;

import java.io.Serializable;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.jsp.JspException;
import javax.servlet.jsp.PageContext;
import javax.servlet.jsp.tagext.Tag;

/**
 * UIResourceTag
 * 
 * @author leesangboo
 * 
 */
public class UIResourceTag extends TagHelper implements Tag, Serializable {

	private static final long serialVersionUID = 1L;

	private PageContext pc = null;

	private Tag parent = null;

	private String id = "";

	public void setPageContext(PageContext p) {
		pc = p;
	}

	public void setParent(Tag t) {
		parent = t;
	}

	public Tag getParent() {
		return parent;
	}

	public int doStartTag() throws JspException {
		try {

			//
			long now = System.currentTimeMillis();

			//
			String contextPath = ((HttpServletRequest) pc.getRequest()).getContextPath();
			String cssPath = contextPath + TagConstants.CSS_PATH;
			String jsPath = contextPath + TagConstants.JS_PATH;
			String theme = super.getUserTheme(pc).getName();
			String themeCssPath = contextPath + super.getUserTheme(pc).getCssPath();
			String themeImagesPath = contextPath + super.getUserTheme(pc).getImagesDirPath();
			String language = super.getUserLocale(pc).getLanguage();

			String userAgent = super.getRequest(pc).getHeader("User-Agent");

			StringBuffer htmlBuffer = new StringBuffer();

			// CSS
			htmlBuffer.append("<link type=\"text/css\" charset=\"utf-8\" href=\"" + themeCssPath + "/include.css?" + now + "\"  rel=\"stylesheet\" media=\"all\" />").append("\n");
			htmlBuffer.append("<link type=\"text/css\" charset=\"utf-8\" href=\"" + themeCssPath + "/application.css?" + now + "\" rel=\"stylesheet\" media=\"all\" />").append("\n");
			htmlBuffer.append("<link type=\"text/css\" charset=\"utf-8\" href=\"" + themeCssPath + "/html.css?" + now + "\" rel=\"stylesheet\" media=\"all\" />").append("\n");
			htmlBuffer.append("<link type=\"text/css\" charset=\"utf-8\" href=\"" + themeCssPath + "/base.css?" + now + "\" rel=\"stylesheet\" media=\"all\" />").append("\n");
			htmlBuffer.append("<link type=\"text/css\" charset=\"utf-8\" href=\"" + themeCssPath + "/ui.css?" + now + "\" rel=\"stylesheet\" media=\"all\" />").append("\n");

			// 브라우저 벤더/버전별 보정용 CSS 추가
			userAgent = userAgent.toLowerCase();
			if (userAgent.indexOf("msie 8") > -1) {
				htmlBuffer.append("<link type=\"text/css\" charset=\"utf-8\" href=\"" + themeCssPath + "/revision_ie8.css?" + now + "\" rel=\"stylesheet\" media=\"all\" />").append("\n");
			} else if (userAgent.indexOf("msie 7") > -1) {
				htmlBuffer.append("<link type=\"text/css\" charset=\"utf-8\" href=\"" + themeCssPath + "/revision_ie7.css?" + now + "\" rel=\"stylesheet\" media=\"all\" />").append("\n");
			} else if (userAgent.indexOf("msie 6") > -1) {
				htmlBuffer.append("<link type=\"text/css\" charset=\"utf-8\" href=\"" + themeCssPath + "/revision_ie6.css?" + now + "\" rel=\"stylesheet\" media=\"all\" />").append("\n");
			} else if (userAgent.indexOf("firefox/") > -1) {
				htmlBuffer.append("<link type=\"text/css\" charset=\"utf-8\" href=\"" + themeCssPath + "/revision_ff.css?" + now + "\" rel=\"stylesheet\" media=\"all\" />").append("\n");
			} else {
				//
			}

			// JS
			htmlBuffer.append("<script type=\"text/javascript\" charset=\"utf-8\">").append("\n");
			htmlBuffer.append("//<![CDATA[ ").append("\n");
			htmlBuffer.append(" var _web_context = { ").append("\n");
			htmlBuffer.append("        path     : '" + contextPath + "', ").append("\n");
			htmlBuffer.append("        jsPath   : '" + jsPath + "', ").append("\n");
			htmlBuffer.append("        cssPath  : '" + cssPath + "', ").append("\n");
			htmlBuffer.append("        language : '" + language + "', ").append("\n");
			htmlBuffer.append("        theme    : '" + theme + "',  ").append("\n");
			htmlBuffer.append("        themeCssPath    : '" + themeCssPath + "',  ").append("\n");
			htmlBuffer.append("        themeImagesPath : '" + themeImagesPath + "'  ").append("\n");
			htmlBuffer.append("	}; ").append("\n");
			htmlBuffer.append("//]]>").append("\n");
			htmlBuffer.append("</script>").append("\n");
			htmlBuffer.append("<script type=\"text/javascript\" charset=\"utf-8\" src=\"" + jsPath + "/include.js?" + now + "\"></script>").append("\n");
			htmlBuffer.append("<script type=\"text/javascript\" charset=\"utf-8\" src=\"" + jsPath + "/application.js?" + now + "\"></script>").append("\n");
			htmlBuffer.append("<script type=\"text/javascript\" charset=\"utf-8\" src=\"" + jsPath + "/api.js?" + now + "\"></script>").append("\n");

			//
			pc.getOut().write(htmlBuffer.toString());

			//

		} catch (Exception e) {
			throw new UITagException("UIResourceTag Exception : " + e.getMessage());
		}
		return SKIP_BODY;
	}

	public int doEndTag() throws JspException {
		return EVAL_PAGE;
	}

	public void release() {
		pc = null;
		parent = null;

		id = "";
	}

	public PageContext getPc() {
		return pc;
	}

	public void setPc(PageContext pc) {
		this.pc = pc;
	}

	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

}
